var addTemplateDialog;
var trTemplate;
var templateFields = ['id', 'name', 'piece_quantity', 'piece_type',
	'piece_weight', 'piece_width', 'piece_height', 'piece_length',
	'piece_nonStandard', 'piece_euroReturn',
	'content', 'comment', 'reference', 'costs_center',
	'service_insurance', 'service_insurance_value', 'service_predeliveryInformation'
];

const isIndexCheckBox = function (index) {
	if (
		'piece_nonStandard' === index
		|| 'piece_euroReturn' === index
		|| 'service_insurance' === index
		|| 'service_predeliveryInformation' === index
	) {
		return true;
	}
	return false;
}

const b64toBlob = (b64Data, contentType = '', sliceSize = 512) => {
	const byteCharacters = atob(b64Data);
	const byteArrays = [];

	for (let offset = 0; offset < byteCharacters.length; offset += sliceSize) {
		const slice = byteCharacters.slice(offset, offset + sliceSize);

		const byteNumbers = new Array(slice.length);
		for (let i = 0; i < slice.length; i++) {
			byteNumbers[i] = slice.charCodeAt(i);
		}

		const byteArray = new Uint8Array(byteNumbers);
		byteArrays.push(byteArray);
	}

	const blob = new Blob(byteArrays, { type: contentType });
	return blob;
}

const showNotice = function (type, message) {
	jQuery('#wpbody .wp-header-end').after('<div class="notice notice-' + type + '"><p>' + message + '</p></div>');
}

const updateHours = function (data) {
	jQuery('#dhl24_pickup_from').children().remove();
	jQuery('#dhl24_pickup_to').children().remove();
	var last_index = data.length - 1;
	var selected_from = ' selected="selected"';
	var selected_to = '';
	jQuery.each(data, function (index, element) {
		if (index == last_index) {
			selected_to = ' selected="selected"';
		}
		jQuery('#dhl24_pickup_from').append('<option value="' + element + '"' + selected_from + '>' + element + '</option>');
		jQuery('#dhl24_pickup_to').append('<option value="' + element + '"' + selected_to + '>' + element + '</option>');
		selected_from = '';
	})
}

const showOpenHours = function (day) {
	var openHours = '';
	if (jQuery('#dhl24_open_hours').length) {
		openHours = jQuery('#dhl24_open_hours').data('openHours');
		if (undefined !== openHours[day]) {
			jQuery('#dhl24_open_hours').html(openHours[day]);
		}
	}
}

const onChangePickupDate = function () {
	var date = this.value;
	var drPickup = jQuery(this).data('dr_pickup') || '0';

	jQuery.post({
		url: dhl24_api.ajax_url,
		dataType: 'json',
		data: {
			action: 'dhl24_get_service',
			_nonce: dhl24_api._nonce,
			date: date,
			post_code: dhl24_oc.post_code,
			service_type: dhl24_oc.service_type,
			dr_pickup: drPickup,
		}
	})
		.done(function (data) {
			updateHours(data);
		})
		.fail(function (data) {
			showNotice('error', data.responseJSON);
		});
}

var waitForMutex = false;

const onSubmitOrderCourier = function () {
	if (true === waitForMutex) {
		return;
	}
	waitForMutex = true;
	var data = jQuery(this).serializeArray();
	data.action = 'dhl24_order_courier';
	jQuery.post({
		url: dhl24_api.ajax_url,
		dataType: 'json',
		data: data
	})
		.done(function () {
			location.assign(dhl24_api.my_parcels_url);
		})
		.fail(function (data) {
			showNotice('error', data.responseJSON);
		})
		.always(function () {
			jQuery("html, body").scrollTop(0);
			waitForMutex = false;
		});
}

const downloadFile = function () {
	if (true === waitForMutex) {
		return;
	}
	var pdfWindow = window.open('', '_blank');
	pdfWindow.document.write('Loading ...');
	waitForMutex = true;
	var data = jQuery(this).serializeArray();
	jQuery.post({
		url: dhl24_api.ajax_url,
		dataType: 'json',
		data: data
	})
		.done(function (result) {
			var blob = b64toBlob(result.data, result.mimeType);
			const blobUrl = URL.createObjectURL(blob);
			pdfWindow.location.href = blobUrl;
			var id = result.id || '';
			if (id) {
				location.assign(dhl24_api.order_edit_url + id);
			}
		})
		.fail(function (result) {
			pdfWindow.close();
			jQuery.each(result.responseJSON, function (index, element) {
				if ('string' === typeof element || element instanceof String) {
					showNotice('error', element);
				} else {
					showNotice(element.type, element.message);
				}
			})
		})
		.always(function () {
			jQuery("html, body").scrollTop(0);
			waitForMutex = false;
		});
}

const addItemToPieces = function (piecesHolder) {
	var prototype = piecesHolder.data('prototype');
	var index = piecesHolder.data('index') || 1;

	var newItem = prototype;
	newItem = newItem.replace(/__index__/g, index);

	piecesHolder.data('index', index + 1);
	piecesHolder.append(newItem);
}

const toggleButtons = function (piecesHolder) {
	var items = piecesHolder.children();
	var lastIndex = items.length - 1;
	items.each(function (index, element) {
		if (0 === lastIndex) {
			jQuery(element).find('.dhl24-delete-piece').hide();
		} else {
			jQuery(element).find('.dhl24-delete-piece').show();
		}
		if (lastIndex === index) {
			jQuery(element).find('.dhl24-add-piece').show();
		} else {
			jQuery(element).find('.dhl24-add-piece').hide();
		}
	});
}

const toggleInputSize = function (index, disabled) {
	jQuery('.dhl24-size-' + index + ' input').prop("disabled", disabled);
}
const toggleInputPallet = function (index, disabled) {
	jQuery('.dhl24-pallet-' + index + ' input').prop("disabled", disabled);
}

const onClickAddPiece = function () {
	var piecesHolder = jQuery('#dhl24-pieces');
	if (piecesHolder.length) {
		addItemToPieces(piecesHolder);
		toggleButtons(piecesHolder);
	}
}

const onClickDeletePiece = function () {
	var piecesHolder = jQuery('#dhl24-pieces');
	if (piecesHolder.children().length > 1) {
		jQuery(this).parentsUntil(piecesHolder).remove();
		toggleButtons(piecesHolder);
	}
}

const onClickAddTemplate = function () {
	addTemplateDialog.dialog('option', 'title', 'Dodaj wzorzec');
	openTemplateDialog();
}

const onClickEditTemplate = function () {
	addTemplateDialog.dialog('option', 'title', 'Edytuj wzorzec');
	trTemplate = jQuery(this).parentsUntil('tbody', 'tr').get(0);
	openTemplateDialog();
}

const onClickDeleteTemplate = function () {
	trTemplate = jQuery(this).parentsUntil('tbody', 'tr').get(0);
	if (undefined !== trTemplate) {
		var template = jQuery(trTemplate).data('template') || '';
		var id = template['id'] || 0;
		if (0 === id) {
			return;
		}

		if (true === waitForMutex) {
			return;
		}
		waitForMutex = true;

		var data = {
			action: 'dhl24_template_delete',
			'template_delete': {
				_nonce: template._nonce,
				id: template.id
			}
		}

		jQuery.post({
			url: dhl24_api.ajax_url,
			dataType: 'json',
			data: data
		})
			.done(function (result) {
				location.reload();
			})
			.fail(function (data) {
				jQuery.each(data.responseJSON, function (index, element) {
					if ('string' === typeof element || element instanceof String) {
						showNotice('error', element);
					} else {
						showNotice(element.type, element.message);
					}
				})
			})
			.always(function () {
				jQuery("html, body").scrollTop(0);
				waitForMutex = false;
			});
	}
}

const onChangeTemplates = function () {
	var id = this.value;
	if ('' === id) {
		return;
	}
	var templateFields = jQuery(this).find('option[value="' + id + '"]').data('template');

	jQuery.each(templateFields, function (index, value) {
		if ('piece_type' === index) {
			jQuery('.dhl24_' + index).val(value).change();
		} else if (isIndexCheckBox(index)) {
			jQuery('.dhl24_' + index).prop('checked', value).change();
		} else {
			if ('' !== value) {
				jQuery('.dhl24_' + index).val(value);
			}
		}
	})

	jQuery(this).val('').change();

}

const openTemplateDialog = function () {
	if (undefined !== trTemplate) {
		var template = jQuery(trTemplate).data('template') || '';

		jQuery.each(templateFields, function (i, el) {
			if ('piece_type' === el) {
				jQuery('#dhl24_template_' + el).val(template[el]).change();
			} else if (isIndexCheckBox(el)) {
				if (true === template[el]) {
					jQuery('#dhl24_template_' + el).prop('checked', true).change();
				} else {
					jQuery('#dhl24_template_' + el).prop('checked', false).change();
				}
			} else {
				jQuery('#dhl24_template_' + el).val(template[el]);
			}
		})
	}
	addTemplateDialog.dialog('open');
}

const saveTemplate = function () {
	if (true === waitForMutex) {
		return;
	}
	waitForMutex = true;
	var templateForm = jQuery('#templateForm');

	var data = templateForm.serializeArray();
	jQuery.post({
		url: dhl24_api.ajax_url,
		dataType: 'json',
		data: data
	})
		.done(function (result) {
			location.reload();
		})
		.fail(function (data) {
			jQuery.each(data.responseJSON, function (index, element) {
				if ('string' === typeof element || element instanceof String) {
					showNotice('error', element);
				} else {
					showNotice(element.type, element.message);
				}
			})
		})
		.always(function () {
			jQuery("html, body").scrollTop(0);
			addTemplateDialog.dialog('close');
			waitForMutex = false;
		});
}

const onChangeTypePiece = function () {
	var index = this.name.match(/\d+/g);

	if (null === index) {
		return;
	}
	index = index[0];
	if ('ENVELOPE' === this.value) {
		toggleInputSize(index, true);
	} else {
		toggleInputSize(index, false);
	}
	if ('PALLET' === this.value) {
		toggleInputPallet(index, false);
	} else {
		toggleInputPallet(index, true);
	}
}

jQuery(document).ready(function ($) {
	addTemplateDialog = jQuery('#addTemplateDialog').dialog({
		autoOpen: false,
		modal: true,
		resizable: false,
		minWidth: 1000,
		buttons: {
			Save: {
				text: "Zapisz",
				click: saveTemplate,
			},
			Cancel: {
				text: "Anuluj",
				click: function () {
					addTemplateDialog.dialog("close");
				},
			}
		},
		close: function () {
			trTemplate = undefined;
			jQuery.each(templateFields, function (i, el) {
				if ('piece_type' === el) {
					jQuery('#dhl24_template_' + el).val('ENVELOPE').change();
				} else if (isIndexCheckBox(el)) {
					jQuery('#dhl24_template_' + el).prop('checked', false).change();
				} else {
					jQuery('#dhl24_template_' + el).val('');
				}

			});
		}
	});

	jQuery('#dhl24_from').datepicker({
		dateFormat: 'yy-mm-dd'
	});

	jQuery('#dhl24_to').datepicker({
		dateFormat: 'yy-mm-dd'
	});

	if (jQuery('#dhl24_label_exp_date').length) {
		let minDate = jQuery('#dhl24_label_exp_date').data('min') || '+7d';
		jQuery('#dhl24_label_exp_date').datepicker({
			dateFormat: 'yy-mm-dd',
			minDate: minDate
		});
	}

	jQuery('#dhl24_shipment_confirmation_date').datepicker({
		dateFormat: 'yy-mm-dd'
	});


	jQuery('#dhl24_pickup_date').on('change', onChangePickupDate);

	jQuery('#dhl24-order-courier').on('submit', onSubmitOrderCourier);

	jQuery('#dhl24-new-shipment').on('submit', downloadFile);

	jQuery('#dhl24-return-shipment').on('submit', downloadFile);

	jQuery('#dhl24Confimation').on('submit', downloadFile);

	jQuery('#dhl24-choose-parcel').on('click', function () {
		jQuery('#dhl24-mapa').show();
	});

	jQuery('body').on('click', '.dhl24-add-piece', onClickAddPiece);
	jQuery('body').on('click', '.dhl24-delete-piece', onClickDeletePiece);
	jQuery('body').on('change', '.dhl24_piece_type', onChangeTypePiece);


	jQuery('#dhl24_add_template').on('click', onClickAddTemplate);
	jQuery('body').on('click', '.dhl24_edit_template', onClickEditTemplate);
	jQuery('body').on('click', '.dhl24_delete_template', onClickDeleteTemplate);
	jQuery('#dhl24_templates').on('change', onChangeTemplates);

	if (jQuery('#dhl24_select_day').length) {
		showOpenHours(jQuery('#dhl24_select_day').val());

		jQuery('#dhl24_select_day').on('change', function () {
			showOpenHours(this.value);
		});
	};
});
