<?php
/**
 * Class ViewOrderController.
 *
 * @package ILabs\WoocommerceDHL24
 */

declare(strict_types=1);
namespace ILabs\WoocommerceDHL24\Controller;

use WC_Order;
use ILabs\WoocommerceDHL24\Exception\ExceptionInterface;
use ILabs\WoocommerceDHL24\Repository\ShipmentRepository;

/**
 * ViewOrderController
 */
class ViewOrderController extends AbstractController implements ControllerInterface {

	/**
	 * Init class.
	 */
	public function init() {
		add_action( 'woocommerce_order_details_after_customer_details', array( $this, 'order_details_after_customer_details' ) );
	}

	/**
	 * Order details after customer details
	 *
	 * @param  WC_Order $order Order data.
	 * @return void
	 */
	public function order_details_after_customer_details( WC_Order $order ) {
		$shipment_id = $order->get_meta( 'dhl24_shipment_id' );
		if ( empty( $shipment_id ) ) {
			return;
		}

		$shipment_repository = new ShipmentRepository();
		try {
			$tracking = $shipment_repository->fetch_tracking( $shipment_id );
		} catch ( ExceptionInterface $e ) {
			return;
		}

		$this->render(
			'order-details-after-customer-details.php',
			array(
				'tracking'    => $tracking,
				'shipment_id' => $shipment_id,
			)
		);
	}
}
