<?php
/**
 * Trait CastTrait
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Convert;

use ILabs\WoocommerceDHL24\Exception\ConvertException;

/**
 * CastTrait
 */
trait CastTrait {

	/**
	 * Source object cast to destination object.
	 *
	 * @param string    $className Destination class name.
	 * @param \stdClass $sourceObject Source object.
	 * @param array     $map Map array.
	 * @return mixed
	 * @throws ConvertException If error.
	 */
	private function castObject( string $className, \stdClass $sourceObject, array $map = array() ) {
		$destinationObject     = $this->getDesctinationObject( $className, $map );
		$sourceReflection      = new \ReflectionObject( $sourceObject );
		$destinationReflection = new \ReflectionObject( $destinationObject );
		$sourceProperties      = $sourceReflection->getProperties();
		foreach ( $sourceProperties as $sourceProperty ) {
			$items = null;
			$name  = $sourceProperty->getName();
			$value = $sourceProperty->getValue( $sourceObject );
			if ( $value instanceof \stdClass ) {
				if ( isset( $value->item ) && is_array( $value->item ) ) {
					$items = $value->item;
				} else {
					$value = $this->castObject( $name, $value, $map );
				}
			}
			if ( null !== $items ) {
				foreach ( $items as $item ) {
					$itemObject = $this->castObject( $name, $item, $map );
					$addMethod  = 'add' . \ucfirst( $this->pluralToSingular( $name ) );
					$destinationObject->$addMethod( $itemObject );
				}
			} else {
				$setMethod = 'set' . \ucfirst( $name );
				if ( $destinationReflection->hasMethod( $setMethod ) ) {
					$destinationObject->$setMethod( $value );
				} else {
					throw new ConvertException( null, 'Error Cast: ' . $className . '|' . $name );
				}
			}
		}
		return $destinationObject;
	}

	/**
	 * Get desctination object
	 *
	 * @param string $className Destination class name.
	 * @param array  $map Map array.
	 * @return mixed
	 */
	private function getDesctinationObject( string $className, array $map = array() ) {
		if ( isset( $map[ $className ] ) ) {
			$className = $map[ $className ];
		}
		$className = substr( __NAMESPACE__, 0, strlen( 'Convert' ) * -1 ) . 'Type\\' . \ucfirst( $className );

		return new $className();
	}

	/**
	 * Plural word to singular.
	 *
	 * @param string $plural Plural word.
	 * @return string
	 */
	private function pluralToSingular( string $plural ): string {
		// Exceptional words.
		$exceptionalWords = array(
			'pieceList' => 'piece',
		);
		if ( isset( $exceptionalWords[ $plural ] ) ) {
			return $exceptionalWords[ $plural ];
		}
		$signular = substr( $plural, 0, -1 );
		if ( empty( $signular ) ) {
			return $plural;
		}
		return $signular;
	}
}
