<?php
/**
 * Class ConvertGetNearestServicepoints
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Convert;

use ILabs\WoocommerceDHL24\Exception\ConvertException;
use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;
use ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Type\NearestServicepoints;

/**
 * ConvertGetNearestServicepoints
 */
class ConvertGetNearestServicepoints implements ConvertInterface {
	use CastTrait;

	/**
	 * Source object cast.
	 *
	 * @param  \stdClass $sourceObject Source object.
	 * @return ResultInterface
	 * @throws ConvertException If error.
	 */
	public function cast( \stdClass $sourceObject ): ResultInterface {
		try {
			$sourceObject = $sourceObject->getNearestServicepointsResult;
		} catch ( \Exception $e ) {
			throw new ConvertException( $e, $e->getMessage() );
		}
		$nearestServicepoints = new NearestServicepoints();
		if ( isset( $sourceObject->count ) && isset( $sourceObject->points->item ) ) {
			$nearestServicepoints->setCount( (int) $sourceObject->count );

			$points = $sourceObject->points->item;
			foreach ( $points as $item ) {
				$point = $this->castObject( 'point', $item, array( 'address' => 'searchAddress' ) );
				$nearestServicepoints->addPoint( $point );
			}
		};
		return $nearestServicepoints;
	}
}
