<?php
/**
 * Class GetPnp
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Type\AuthData;

/**
 * GetPnp
 */
class GetPnp extends AbstractMethod implements RequestInterface {

	/**
	 * Date for which the report is generated (the report lists shipments sent on a specific date).
	 *
	 * @var string
	 */
	private $date;

	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$now        = new \DateTime();
		$this->date = $now->format( 'Y-m-d' );
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'structure' => array_merge(
				parent::toArray(),
				array(
					'shipmentDate' => $this->getDate(),
				)
			),
		);
	}

	/**
	 * Get date for which the report is generated (the report lists shipments sent on a specific date).
	 *
	 * @return string
	 */
	public function getDate() {
		return $this->date;
	}

	/**
	 * Set date for which the report is generated (the report lists shipments sent on a specific date).
	 *
	 * @param string $date Date for which the report is generated (the report lists shipments sent on a specific date).
	 *
	 * @return self
	 */
	public function setDate( string $date ) {
		$this->date = $date;

		return $this;
	}
}
