<?php
/**
 * Class ShipmentData
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Type;

use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;

/**
 * ShipmentData
 */
class ShipmentData implements ResultInterface {
	/**
	 * Parcel ID.
	 *
	 * @var string|null
	 */
	private $shipmentId;

	/**
	 * Shipment creation date in YYYY-MM-DD format.
	 *
	 * @var string|null
	 */
	private $created;

	/**
	 * Sender data communicated in the address structure.
	 *
	 * @var Address|null
	 */
	private $shipper;

	/**
	 * Recipient data communicated in the address structure.
	 *
	 * @var Address|null
	 */
	private $receiver;

	/**
	 * Information whether a courier is booked for this shipment.
	 *
	 * @var string|null
	 */
	private $orderStatus;

	/**
	 * Get parcel ID.
	 *
	 * @return string|null
	 */
	public function getShipmentId() {
		return $this->shipmentId;
	}

	/**
	 * Set parcel ID.
	 *
	 * @param string|null $shipmentId Parcel ID.
	 *
	 * @return self
	 */
	public function setShipmentId( $shipmentId ) {
		$this->shipmentId = $shipmentId;

		return $this;
	}

	/**
	 * Get shipment creation date in YYYY-MM-DD format.
	 *
	 * @return string|null
	 */
	public function getCreated() {
		return $this->created;
	}

	/**
	 * Set shipment creation date in YYYY-MM-DD format.
	 *
	 * @param string|null $created Shipment creation date in YYYY-MM-DD format.
	 *
	 * @return self
	 */
	public function setCreated( $created ) {
		$this->created = $created;

		return $this;
	}

	/**
	 * Get sender data communicated in the address structure.
	 *
	 * @return Address|null
	 */
	public function getShipper() {
		return $this->shipper;
	}

	/**
	 * Set sender data communicated in the address structure.
	 *
	 * @param Address|null $shipper Sender data communicated in the address structure.
	 *
	 * @return self
	 */
	public function setShipper( $shipper ) {
		$this->shipper = $shipper;

		return $this;
	}

	/**
	 * Get recipient data communicated in the address structure.
	 *
	 * @return Address|null
	 */
	public function getReceiver() {
		return $this->receiver;
	}

	/**
	 * Set recipient data communicated in the address structure.
	 *
	 * @param Address|null $receiver Recipient data communicated in the address structure.
	 *
	 * @return self
	 */
	public function setReceiver( $receiver ) {
		$this->receiver = $receiver;

		return $this;
	}

	/**
	 * Get information whether a courier is booked for this shipment.
	 *
	 * @return string|null
	 */
	public function getOrderStatus() {
		return $this->orderStatus;
	}

	/**
	 * Set information whether a courier is booked for this shipment.
	 *
	 * @param string|null $orderStatus Information whether a courier is booked for this shipment.
	 *
	 * @return self
	 */
	public function setOrderStatus( $orderStatus ) {
		$this->orderStatus = $orderStatus;

		return $this;
	}
}
