<?php
/**
 * Class ConvertDeleteShipments
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Convert;

use ILabs\WoocommerceDHL24\Exception\ConvertException;
use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\DeleteNotifications;

/**
 * ConvertDeleteShipments
 */
class ConvertDeleteShipments implements ConvertInterface {
	use CastTrait;

	/**
	 * Source object cast.
	 *
	 * @param \stdClass $sourceObject Source object.
	 * @return ResultInterface
	 * @throws ConvertException If error.
	 */
	public function cast( \stdClass $sourceObject ): ResultInterface {
		try {
			$sourceObject = $sourceObject->deleteShipmentsResult;
		} catch ( \Exception $e ) {
			throw new ConvertException( $e, $e->getMessage() );
		}
		$deleteNotifications = new DeleteNotifications();
		if ( isset( $sourceObject->item ) ) {
			$items = $sourceObject->item;
			foreach ( $items as $item ) {
				$deleteNotification = $this->castObject( 'deleteNotification', $item );
				$deleteNotifications->addItem( $deleteNotification );
			};
		}

		return $deleteNotifications;
	}
}
