<?php
/**
 * Class ConvertGetInternationalParams
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Convert;

use ILabs\WoocommerceDHL24\Exception\ConvertException;
use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\InternationalParams;

/**
 * ConvertGetInternationalParams
 */
class ConvertGetInternationalParams implements ConvertInterface {
	use CastTrait;

	/**
	 * Source object cast.
	 *
	 * @param \stdClass $sourceObject Source object.
	 * @return ResultInterface
	 * @throws ConvertException If error.
	 */
	public function cast( \stdClass $sourceObject ): ResultInterface {
		try {
			$sourceObject = $sourceObject->getInternationalParamsResult;
		} catch ( \Exception $e ) {
			throw new ConvertException( $e, $e->getMessage() );
		}
		$internationalParams = new InternationalParams();
		if ( isset( $sourceObject->count ) && isset( $sourceObject->params->item ) ) {
			$internationalParams->setCount( (int) $sourceObject->count );

			$params = $sourceObject->params->item;
			foreach ( $params as $param ) {
				$internationalParam = $this->castObject( 'internationalParam', $param );
				$internationalParams->addParam( $internationalParam );
			}
		}
		return $internationalParams;
	}
}
