<?php
/**
 * Class ConvertGetInternationalParams2
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Convert;

use ILabs\WoocommerceDHL24\Exception\ConvertException;
use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\InternationalParams2;

/**
 * ConvertGetInternationalParams2
 */
class ConvertGetInternationalParams2 implements ConvertInterface {
	use CastTrait;

	/**
	 * Source object cast.
	 *
	 * @param \stdClass $sourceObject Source object.
	 * @return ResultInterface
	 * @throws ConvertException If error.
	 */
	public function cast( \stdClass $sourceObject ): ResultInterface {
		try {
			$sourceObject = $sourceObject->getInternationalParams2Result;
		} catch ( \Exception $e ) {
			throw new ConvertException( $e, $e->getMessage() );
		}
		$internationalParams2 = new InternationalParams2();
		if ( isset( $sourceObject->params->item ) ) {
			$params = $sourceObject->params->item;
			foreach ( $params as $param ) {
				$pip2Country = $this->castObject( 'pip2Country', $param, array( 'products' => 'pip2Param' ) );
				$internationalParams2->addParam( $pip2Country );
			}
		}
		return $internationalParams2;
	}
}
