<?php
/**
 * Class ConvertGetLabels
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Convert;

use ILabs\WoocommerceDHL24\Exception\ConvertException;
use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\Pnp;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\Labels;

/**
 * ConvertGetLabels
 */
class ConvertGetLabels implements ConvertInterface {
	use CastTrait;

	/**
	 * Source object cast.
	 *
	 * @param \stdClass $sourceObject Source object.
	 * @return ResultInterface
	 * @throws ConvertException If error.
	 */
	public function cast( \stdClass $sourceObject ): ResultInterface {
		try {
			$sourceObject = $sourceObject->getLabelsResult;
		} catch ( \Exception $e ) {
			throw new ConvertException( $e, $e->getMessage() );
		}

		$labels = new Labels();
		if ( isset( $sourceObject->item ) ) {
			$items = $sourceObject->item;
			foreach ( $items as $item ) {
				$label = $this->castObject( 'labelsItem', $item );
				$labels->addItem( $label );
			};
		}

		return $labels;
	}
}
