<?php
/**
 * Class ConvertGetLabelsData
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Convert;

use ILabs\WoocommerceDHL24\Exception\ConvertException;
use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\LabelsDatas;

/**
 * ConvertGetLabelsData
 */
class ConvertGetLabelsData implements ConvertInterface {
	use CastTrait;

	/**
	 * Source object cast.
	 *
	 * @param \stdClass $sourceObject Source object.
	 * @return ResultInterface
	 * @throws ConvertException If error.
	 */
	public function cast( \stdClass $sourceObject ): ResultInterface {
		try {
			$sourceObject = $sourceObject->getLabelsDataResult;
		} catch ( \Exception $e ) {
			throw new ConvertException( $e, $e->getMessage() );
		}
		$labelsDatas = new LabelsDatas();
		if ( isset( $sourceObject->item ) ) {
			$items = $sourceObject->item;
			foreach ( $items as $item ) {
				$labelsData = $this->castObject(
					'labelsData',
					$item,
					array(
						'shipmentTime' => 'shipmentTimeLabel',
						'shipper'      => 'shipperAddressLabel',
						'receiver'     => 'receiverAddressLabel',
						'neighbour'    => 'neighbourAddress',
						'servicepoint' => 'servicePoint',
						'service'      => 'labelDataServiceDefinition',
						'pieceList'    => 'pieceDefinitionLabel',
					)
				);
				$labelsDatas->addItem( $labelsData );
			};
		}

		return $labelsDatas;
	}
}
