<?php
/**
 * Class ConvertGetReturnByWaybill
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Convert;

use ILabs\WoocommerceDHL24\Exception\ConvertException;
use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\Shipments;

/**
 * ConvertGetReturnByWaybill
 */
class ConvertGetReturnByWaybill implements ConvertInterface {
	use CastTrait;

	/**
	 * Source object cast.
	 *
	 * @param \stdClass $sourceObject Source object.
	 * @return ResultInterface
	 * @throws ConvertException If error.
	 */
	public function cast( \stdClass $sourceObject ): ResultInterface {
		try {
			$sourceObject = $sourceObject->getReturnByWaybillResult;
		} catch ( \Exception $e ) {
			throw new ConvertException( $e, $e->getMessage() );
		}

		$shipments = new Shipments();
		if ( isset( $sourceObject->item ) ) {
			$items = $sourceObject->item;
			foreach ( $items as $item ) {
				$shipment = $this->castObject( 'shipment', $item );
				$shipments->addItem( $shipment );
			};
		}

		return $shipments;
	}
}
