<?php
/**
 * Class ConvertGetReturnParams
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Convert;

use ILabs\WoocommerceDHL24\Exception\ConvertException;
use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\ReturnParams;

/**
 * ConvertGetReturnParams
 */
class ConvertGetReturnParams implements ConvertInterface {
	use CastTrait;

	/**
	 * Source object cast.
	 *
	 * @param \stdClass $sourceObject Source object.
	 * @return ResultInterface
	 * @throws ConvertException If error.
	 */
	public function cast( \stdClass $sourceObject ): ResultInterface {
		try {
			$sourceObject = $sourceObject->getReturnParamsResult;
		} catch ( \Exception $e ) {
			throw new ConvertException( $e, $e->getMessage() );
		}
		$returnParams = new ReturnParams();
		if ( isset( $sourceObject->count ) && isset( $sourceObject->params->item ) ) {
			$returnParams->setCount( (int) $sourceObject->count );

			$params = $sourceObject->params->item;
			foreach ( $params as $param ) {
				$returnParam = $this->castObject( 'returnParam', $param );
				$returnParams->addParam( $returnParam );
			}
		}
		return $returnParams;
	}
}
