<?php
/**
 * Class GetLabelsData
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\AuthData;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\ItemToLabelData;

/**
 * GetLabelsData
 */
class GetLabelsData extends AbstractMethod implements RequestInterface {
	/**
	 * Array of itemsToLabelData type structures.
	 *
	 * @var \ArrayObject|ItemToLabelData[]
	 */
	private $itemsToLabelData;

	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->itemsToLabelData = new \ArrayObject();
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		$itemsToLabelData = array();
		foreach ( $this->getItemsToLabelData() as $key => $value ) {
			$itemsToLabelData[] = $value->toArray();
		}
		return array_merge(
			parent::toArray(),
			array(
				'itemsToLabelData' => $itemsToLabelData,
			)
		);
	}

	/**
	 * Get array of itemsToLabelData type structures.
	 *
	 * @return \ArrayObject|ItemToLabelData[]
	 */
	public function getItemsToLabelData() {
		return $this->itemsToLabelData;
	}

	/**
	 * Add ItemToLabelData.
	 *
	 * @param ItemToLabelData $itemToLabelData ItemToLabelData.
	 *
	 * @return self
	 */
	public function addItemToLabelData( ItemToLabelData $itemToLabelData ) {
		$this->itemsToLabelData->append( $itemToLabelData );

		return $this;
	}

	/**
	 * Remove ItemToLabelData.
	 *
	 * @param ItemToLabelData $itemToLabelData ItemToLabelData.
	 *
	 * @return self
	 */
	public function removeItemToLabelData( ItemToLabelData $itemToLabelData ) {
		// TODO.

		return $this;
	}
}
