<?php
/**
 * Class GetPieceId
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\AuthData;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\PieceShipmentItem;

/**
 * GetPieceId
 */
class GetPieceId extends AbstractMethod implements RequestInterface {

	/**
	 * Array of structures of PieceShipmentItem type.
	 *
	 * @var \ArrayObject|PieceShipmentItem[]
	 */
	private $items;

	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->items = new \ArrayObject();
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		$items = array();
		foreach ( $this->getItems() as $key => $value ) {
			$items[] = $value->toArray();
		}
		return array_merge(
			parent::toArray(),
			array(
				'request' => array(
					'items' => $items,
				),
			)
		);
	}


	/**
	 * Get array of structures of PieceShipmentItem type.
	 *
	 * @return  \ArrayObject|PieceShipmentItem[]
	 */
	public function getItems() {
		return $this->items;
	}

	/**
	 * Add PieceShipmentItem.
	 *
	 * @param PieceShipmentItem $item PieceShipmentItem.
	 *
	 * @return  self
	 */
	public function addItem( PieceShipmentItem $item ) {
		$this->items->append( $item );

		return $this;
	}

	/**
	 * Remove PieceShipmentItem.
	 *
	 * @param PieceShipmentItem $item PieceShipmentItem.
	 *
	 * @return  self
	 */
	public function removeItem( PieceShipmentItem $item ) {
		// TODO.

		return $this;
	}
}
