<?php
/**
 * Class GetShipmentScan
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\AuthData;

/**
 * GetShipmentScan
 */
class GetShipmentScan extends AbstractMethod implements RequestInterface {

	/**
	 * Shipment ID number.
	 *
	 * @var string
	 */
	private $shipmentId;

	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->shipmentId = '';
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array_merge(
			parent::toArray(),
			array(
				'shipmentId' => $this->getShipmentId(),
			)
		);
	}


	/**
	 * Get shipment ID number.
	 *
	 * @return string
	 */
	public function getShipmentId() {
		return $this->shipmentId;
	}

	/**
	 * Set shipment ID number.
	 *
	 * @param string $shipmentId Shipment ID number.
	 *
	 * @return self
	 */
	public function setShipmentId( string $shipmentId ) {
		$this->shipmentId = $shipmentId;

		return $this;
	}
}
