<?php
/**
 * Class LabelsData
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * LabelsData
 */
class LabelsData {

	/**
	 * Shipment number of the shipment for which information is to be downloaded.
	 *
	 * @var string|null
	 */
	private $shipmentId;

	/**
	 * Original shipment number.
	 *
	 * @var string|null
	 */
	private $primaryWaybillNumber;

	/**
	 * Order ID (if courier is booked).
	 *
	 * @var string|null
	 */
	private $dispatchNotificationNumber;

	/**
	 * Label header.
	 *
	 * @var string|null
	 */
	private $labelHeader;

	/**
	 * Content of the parcel.
	 *
	 * @var string|null
	 */
	private $content;

	/**
	 * Additional comments (visible on the consignment note).
	 *
	 * @var string|null
	 */
	private $comment;

	/**
	 * Shipment reference number.
	 *
	 * @var string|null
	 */
	private $reference;

	/**
	 * Information on billing .
	 *
	 * @var Billing|null
	 */
	private $billing;

	/**
	 * Information on the parcel shipment time.
	 *
	 * @var ShipmentTimeLabel|null|null
	 */
	private $shipmentTime;

	/**
	 * Data for shipment routing.
	 *
	 * @var Routing|null
	 */
	private $routing;

	/**
	 * Sender address details.
	 *
	 * @var ShipperAddressLabel|null
	 */
	private $shipper;

	/**
	 * Address details of the recipient.
	 *
	 * @var ReceiverAddressLabel|null
	 */
	private $receiver;

	/**
	 * Neighbour details (only if NEI service is selected).
	 *
	 * @var NeighbourAddress|null
	 */
	private $neighbour;

	/**
	 * Serivce point details.
	 *
	 * @var ServicePoint|null
	 */
	private $servicepoint;

	/**
	 * Shipping and additional services.
	 *
	 * @var LabelDataServiceDefinition|null
	 */
	private $service;

	/**
	 * Shipment parcel data.
	 *
	 * @var \ArrayObject|PieceDefinitionLabel[]
	 */
	private $pieceList;

	/**
	 * Construct
	 *
	 * @return void
	 */
	public function __construct() {
		$this->pieceList = new \ArrayObject();
	}

	/**
	 * Get shipment number of the shipment for which information is to be downloaded.
	 *
	 * @return string|null
	 */
	public function getShipmentId() {
		return $this->shipmentId;
	}

	/**
	 * Set shipment number of the shipment for which information is to be downloaded.
	 *
	 * @param string|null $shipmentId Shipment number of the shipment for which information is to be downloaded.
	 *
	 * @return self
	 */
	public function setShipmentId( $shipmentId ) {
		$this->shipmentId = $shipmentId;

		return $this;
	}

	/**
	 * Get original shipment number.
	 *
	 * @return string|null
	 */
	public function getPrimaryWaybillNumber() {
		return $this->primaryWaybillNumber;
	}

	/**
	 * Set original shipment number.
	 *
	 * @param string|null $primaryWaybillNumber Original shipment number.
	 *
	 * @return self
	 */
	public function setPrimaryWaybillNumber( $primaryWaybillNumber ) {
		$this->primaryWaybillNumber = $primaryWaybillNumber;

		return $this;
	}

	/**
	 * Get order ID (if courier is booked).
	 *
	 * @return string|null
	 */
	public function getDispatchNotificationNumber() {
		return $this->dispatchNotificationNumber;
	}

	/**
	 * Set order ID (if courier is booked).
	 *
	 * @param string|null $dispatchNotificationNumber Order ID (if courier is booked).
	 *
	 * @return self
	 */
	public function setDispatchNotificationNumber( $dispatchNotificationNumber ) {
		$this->dispatchNotificationNumber = $dispatchNotificationNumber;

		return $this;
	}

	/**
	 * Get label header.
	 *
	 * @return string|null
	 */
	public function getLabelHeader() {
		return $this->labelHeader;
	}

	/**
	 * Set label header.
	 *
	 * @param string|null $labelHeader Label header.
	 *
	 * @return self
	 */
	public function setLabelHeader( $labelHeader ) {
		$this->labelHeader = $labelHeader;

		return $this;
	}

	/**
	 * Get content of the parcel.
	 *
	 * @return string|null
	 */
	public function getContent() {
		return $this->content;
	}

	/**
	 * Set content of the parcel.
	 *
	 * @param string|null $content Content of the parcel.
	 *
	 * @return self
	 */
	public function setContent( $content ) {
		$this->content = $content;

		return $this;
	}

	/**
	 * Get additional comments (visible on the consignment note).
	 *
	 * @return string|null
	 */
	public function getComment() {
		return $this->comment;
	}

	/**
	 * Set additional comments (visible on the consignment note).
	 *
	 * @param string|null $comment Additional comments (visible on the consignment note).
	 *
	 * @return self
	 */
	public function setComment( $comment ) {
		$this->comment = $comment;

		return $this;
	}

	/**
	 * Get shipment reference number.
	 *
	 * @return string|null
	 */
	public function getReference() {
		return $this->reference;
	}

	/**
	 * Set shipment reference number.
	 *
	 * @param string|null $reference Shipment reference number.
	 *
	 * @return self
	 */
	public function setReference( $reference ) {
		$this->reference = $reference;

		return $this;
	}

	/**
	 * Get information on billing .
	 *
	 * @return Billing|null
	 */
	public function getBilling() {
		return $this->billing;
	}

	/**
	 * Set information on billing .
	 *
	 * @param Billing|null $billing Information on billing .
	 *
	 * @return self
	 */
	public function setBilling( $billing ) {
		$this->billing = $billing;

		return $this;
	}

	/**
	 * Get information on the parcel shipment time.
	 *
	 * @return ShipmentTimeLabel|null
	 */
	public function getShipmentTime() {
		return $this->shipmentTime;
	}

	/**
	 * Set information on the parcel shipment time.
	 *
	 * @param ShipmentTimeLabel|null $shipmentTime Information on the parcel shipment time.
	 *
	 * @return self
	 */
	public function setShipmentTime( $shipmentTime ) {
		$this->shipmentTime = $shipmentTime;

		return $this;
	}

	/**
	 * Get data for shipment routing.
	 *
	 * @return Routing|null
	 */
	public function getRouting() {
		return $this->routing;
	}

	/**
	 * Set data for shipment routing.
	 *
	 * @param Routing|null $routing Data for shipment routing.
	 *
	 * @return self
	 */
	public function setRouting( $routing ) {
		$this->routing = $routing;

		return $this;
	}

	/**
	 * Get sender address details.
	 *
	 * @return ShipperAddressLabel|null
	 */
	public function getShipper() {
		return $this->shipper;
	}

	/**
	 * Set sender address details.
	 *
	 * @param ShipperAddressLabel|null $shipper Sender address details.
	 *
	 * @return self
	 */
	public function setShipper( $shipper ) {
		$this->shipper = $shipper;

		return $this;
	}

	/**
	 * Get address details of the recipient.
	 *
	 * @return ReceiverAddressLabel|null
	 */
	public function getReceiver() {
		return $this->receiver;
	}

	/**
	 * Set address details of the recipient.
	 *
	 * @param ReceiverAddressLabel|null $receiver Address details of the recipient.
	 *
	 * @return self
	 */
	public function setReceiver( $receiver ) {
		$this->receiver = $receiver;

		return $this;
	}

	/**
	 * Get neighbour details (only if NEI service is selected).
	 *
	 * @return NeighbourAddress|null
	 */
	public function getNeighbour() {
		return $this->neighbour;
	}

	/**
	 * Set neighbour details (only if NEI service is selected).
	 *
	 * @param NeighbourAddress|null $neighbour Neighbour details (only if NEI service is selected).
	 *
	 * @return self
	 */
	public function setNeighbour( $neighbour ) {
		$this->neighbour = $neighbour;

		return $this;
	}

	/**
	 * Get serivce point details.
	 *
	 * @return ServicePoint|null
	 */
	public function getServicepoint() {
		return $this->servicepoint;
	}

	/**
	 * Set serivce point details.
	 *
	 * @param ServicePoint|null $servicepoint Serivce point details.
	 *
	 * @return self
	 */
	public function setServicepoint( $servicepoint ) {
		$this->servicepoint = $servicepoint;

		return $this;
	}

	/**
	 * Get shipping and additional services.
	 *
	 * @return LabelDataServiceDefinition|null
	 */
	public function getService() {
		return $this->service;
	}

	/**
	 * Set shipping and additional services.
	 *
	 * @param LabelDataServiceDefinition|null $service Shipping and additional services.
	 *
	 * @return self
	 */
	public function setService( $service ) {
		$this->service = $service;

		return $this;
	}

	/**
	 * Get shipment parcel data.
	 *
	 * @return \ArrayObject|PieceDefinitionLabel[]
	 */
	public function getPieceList() {
		return $this->pieceList;
	}

	/**
	 * Add shipment parcel data.
	 *
	 * @param PieceDefinitionLabel $piece PieceDefinitionLabel.
	 *
	 * @return self
	 */
	public function addPiece( PieceDefinitionLabel $piece ) {
		$this->pieceList->append( $piece );

		return $this;
	}

	/**
	 * Remove shipment parcel data.
	 *
	 * @param PieceDefinitionLabel $piece PieceDefinitionLabel.
	 *
	 * @return self
	 */
	public function removePiece( PieceDefinitionLabel $piece ) {
		// TODO.

		return $this;
	}
}
