<?php
/**
 * Class LabelsItem
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * LabelsItem
 */
class LabelsItem {
	/**
	 * Shipment number of the shipment for which a label is prepared.
	 *
	 * @var string|null
	 */
	private $shipmentId;

	/**
	 * Label type.
	 *
	 * @var string|null
	 */
	private $labelType;

	/**
	 * Label name.
	 *
	 * @var string|null
	 */
	private $labelName;

	/**
	 * Binary data of the label (encoded in Base64).
	 *
	 * @var string|null
	 */
	private $labelData;

	/**
	 * MIME type of the label to be sent.
	 *
	 * @var string|null
	 */
	private $labelMimeType;

	/**
	 * Contents of customs document CN23 (base24).
	 *
	 * @var string|null
	 */
	private $cn23Data;

	/**
	 * Customs document type CN23.
	 *
	 * @var string|null
	 */
	private $cn23MimeType;

	/**
	 * Contents of proforma invoice (base64).
	 *
	 * @var string|null
	 */
	private $fvProformaData;

	/**
	 * Proforma invoice document type.
	 *
	 * @var string|null
	 */
	private $fvProformaMimeType;

	/**
	 * Generated invoice number.
	 *
	 * @var string|null
	 */
	private $fvProformaNumer;

	/**
	 * Get shipment number of the shipment for which a label is prepared.
	 *
	 * @return string|null
	 */
	public function getShipmentId() {
		return $this->shipmentId;
	}

	/**
	 * Set shipment number of the shipment for which a label is prepared.
	 *
	 * @param string|null $shipmentId Shipment number of the shipment for which a label is prepared.
	 *
	 * @return self
	 */
	public function setShipmentId( $shipmentId ) {
		$this->shipmentId = $shipmentId;

		return $this;
	}

	/**
	 * Get label type.
	 *
	 * @return string|null
	 */
	public function getLabelType() {
		return $this->labelType;
	}

	/**
	 * Set label type.
	 *
	 * @param string|null $labelType Label type.
	 *
	 * @return self
	 */
	public function setLabelType( $labelType ) {
		$this->labelType = $labelType;

		return $this;
	}

	/**
	 * Get label name.
	 *
	 * @return string|null
	 */
	public function getLabelName() {
		return $this->labelName;
	}

	/**
	 * Set label name.
	 *
	 * @param string|null $labelName Label name.
	 *
	 * @return self
	 */
	public function setLabelName( $labelName ) {
		$this->labelName = $labelName;

		return $this;
	}

	/**
	 * Get binary data of the label (encoded in Base64).
	 *
	 * @return string|null
	 */
	public function getLabelData() {
		return $this->labelData;
	}

	/**
	 * Set binary data of the label (encoded in Base64).
	 *
	 * @param string|null $labelData Binary data of the label (encoded in Base64).
	 *
	 * @return self
	 */
	public function setLabelData( $labelData ) {
		$this->labelData = $labelData;

		return $this;
	}

	/**
	 * Get mIME type of the label to be sent.
	 *
	 * @return string|null
	 */
	public function getLabelMimeType() {
		return $this->labelMimeType;
	}

	/**
	 * Set mIME type of the label to be sent.
	 *
	 * @param string|null $labelMimeType MIME type of the label to be sent.
	 *
	 * @return self
	 */
	public function setLabelMimeType( $labelMimeType ) {
		$this->labelMimeType = $labelMimeType;

		return $this;
	}

	/**
	 * Get contents of customs document CN23 (base24).
	 *
	 * @return string|null
	 */
	public function getCn23Data() {
		return $this->cn23Data;
	}

	/**
	 * Set contents of customs document CN23 (base24).
	 *
	 * @param string|null $cn23Data Contents of customs document CN23 (base24).
	 *
	 * @return self
	 */
	public function setCn23Data( $cn23Data ) {
		$this->cn23Data = $cn23Data;

		return $this;
	}

	/**
	 * Get customs document type CN23.
	 *
	 * @return string|null
	 */
	public function getCn23MimeType() {
		return $this->cn23MimeType;
	}

	/**
	 * Set customs document type CN23.
	 *
	 * @param string|null $cn23MimeType Customs document type CN23.
	 *
	 * @return self
	 */
	public function setCn23MimeType( $cn23MimeType ) {
		$this->cn23MimeType = $cn23MimeType;

		return $this;
	}

	/**
	 * Get contents of proforma invoice (base64).
	 *
	 * @return string|null
	 */
	public function getFvProformaData() {
		return $this->fvProformaData;
	}

	/**
	 * Set contents of proforma invoice (base64).
	 *
	 * @param string|null $fvProformaData Contents of proforma invoice (base64).
	 *
	 * @return self
	 */
	public function setFvProformaData( $fvProformaData ) {
		$this->fvProformaData = $fvProformaData;

		return $this;
	}

	/**
	 * Get proforma invoice document type.
	 *
	 * @return string|null
	 */
	public function getFvProformaMimeType() {
		return $this->fvProformaMimeType;
	}

	/**
	 * Set proforma invoice document type.
	 *
	 * @param string|null $fvProformaMimeType Proforma invoice document type.
	 *
	 * @return self
	 */
	public function setFvProformaMimeType( $fvProformaMimeType ) {
		$this->fvProformaMimeType = $fvProformaMimeType;

		return $this;
	}

	/**
	 * Get generated invoice number.
	 *
	 * @return string|null
	 */
	public function getFvProformaNumer() {
		return $this->fvProformaNumer;
	}

	/**
	 * Set generated invoice number.
	 *
	 * @param string|null $fvProformaNumer Generated invoice number.
	 *
	 * @return self
	 */
	public function setFvProformaNumer( $fvProformaNumer ) {
		$this->fvProformaNumer = $fvProformaNumer;

		return $this;
	}
}
