<?php
/**
 * Class NeighbourAddress
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * NeighbourAddress
 */
class NeighbourAddress {
	/**
	 * Company name or first name and surname.
	 *
	 * @var string|null
	 */
	private $name;

	/**
	 * Postal code, without dash.
	 *
	 * @var string|null
	 */
	private $postalCode;

	/**
	 * City name.
	 *
	 * @var string|null
	 */
	private $city;

	/**
	 * Street.
	 *
	 * @var string|null
	 */
	private $street;

	/**
	 * House number.
	 * The sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @var string|null
	 */
	private $houseNumber;

	/**
	 * Apartment number.
	 * The sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @var string|null
	 */
	private $apartmentNumber;

	/**
	 * Contact phone number.
	 *
	 * @var string|null
	 */
	private $contactPhone;

	/**
	 * Contact e-mail.
	 *
	 * @var string|null
	 */
	private $contactEmail;

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'name'            => $this->getName(),
			'postalCode'      => $this->getPostalCode(),
			'city'            => $this->getCity(),
			'street'          => $this->getStreet(),
			'houseNumber'     => $this->getHouseNumber(),
			'apartmentNumber' => $this->getApartmentNumber(),
			'contactPhone'    => $this->getContactPhone(),
			'contactEmail'    => $this->getContactEmail(),
		);
	}

	/**
	 * Get company name or first name and surname.
	 *
	 * @return string|null
	 */
	public function getName() {
		return $this->name;
	}

	/**
	 * Set company name or first name and surname.
	 *
	 * @param string $name Company name or first name and surname.
	 *
	 * @return self
	 */
	public function setName( $name ) {
		$this->name = $name;

		return $this;
	}

	/**
	 * Get postal code, without dash.
	 *
	 * @return string|null
	 */
	public function getPostalCode() {
		return $this->postalCode;
	}

	/**
	 * Set postal code, without dash.
	 *
	 * @param string $postalCode Postal code, without dash.
	 *
	 * @return self
	 */
	public function setPostalCode( $postalCode ) {
		$this->postalCode = $postalCode;

		return $this;
	}

	/**
	 * Get city name.
	 *
	 * @return string|null
	 */
	public function getCity() {
		return $this->city;
	}

	/**
	 * Set city name.
	 *
	 * @param string $city City name.
	 *
	 * @return self
	 */
	public function setCity( $city ) {
		$this->city = $city;

		return $this;
	}

	/**
	 * Get street.
	 *
	 * @return string|null
	 */
	public function getStreet() {
		return $this->street;
	}

	/**
	 * Set street.
	 *
	 * @param string $street Street.
	 *
	 * @return self
	 */
	public function setStreet( $street ) {
		$this->street = $street;

		return $this;
	}

	/**
	 * Get the sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @return string|null
	 */
	public function getHouseNumber() {
		return $this->houseNumber;
	}

	/**
	 * Set the sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @param string $houseNumber The sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @return self
	 */
	public function setHouseNumber( $houseNumber ) {
		$this->houseNumber = $houseNumber;

		return $this;
	}

	/**
	 * Get the sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @return string|null
	 */
	public function getApartmentNumber() {
		return $this->apartmentNumber;
	}

	/**
	 * Set the sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @param string|null $apartmentNumber The sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @return self
	 */
	public function setApartmentNumber( $apartmentNumber ) {
		$this->apartmentNumber = $apartmentNumber;

		return $this;
	}

	/**
	 * Get contact phone number.
	 *
	 * @return string|null
	 */
	public function getContactPhone() {
		return $this->contactPhone;
	}

	/**
	 * Set contact phone number.
	 *
	 * @param string|null $contactPhone Contact phone number.
	 *
	 * @return self
	 */
	public function setContactPhone( $contactPhone ) {
		$this->contactPhone = $contactPhone;

		return $this;
	}

	/**
	 * Get contact e-mail.
	 *
	 * @return string|null
	 */
	public function getContactEmail() {
		return $this->contactEmail;
	}

	/**
	 * Set contact e-mail.
	 *
	 * @param string|null $contactEmail Contact e-mail.
	 *
	 * @return self
	 */
	public function setContactEmail( $contactEmail ) {
		$this->contactEmail = $contactEmail;

		return $this;
	}
}
