<?php
/**
 * Class PostalCodeServices
 *
 * @package ILabs\WoocommerceDHL24
 */

declare (strict_types=1);
namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;

/**
 * PostalCodeServices
 */
class PostalCodeServices implements ResultInterface {
	/**
	 * Availability of Domestic 09 service.
	 *
	 * @var bool
	 */
	private $domesticExpress9 = false;

	/**
	 * Availability of Domestic 12 service.
	 *
	 * @var bool
	 */
	private $domesticExpress12 = false;

	/**
	 * Availability of Evening Delivery service.
	 *
	 * @var bool
	 */
	private $deliveryEvening = false;

	/**
	 * Availability of Saturday Shipment service.
	 *
	 * @var bool
	 */
	private $pickupOnSaturday = false;

	/**
	 * Availability of Saturday Delivery service.
	 *
	 * @var bool
	 */
	private $deliverySaturday = false;

	/**
	 * Time from which express shipments can be collected.
	 *
	 * @var string|null
	 */
	private $exPickupFrom;

	/**
	 * Time to which express shipments can be collected.
	 *
	 * @var string|null
	 */
	private $exPickupTo;

	/**
	 * Time from which general shipments can be collected.
	 *
	 * @var string|null
	 */
	private $drPickupFrom;

	/**
	 * Time to which general shipments can be collected.
	 *
	 * @var string|null
	 */
	private $drPickupTo;

	/**
	 * Get availability of Domestic 09 service.
	 *
	 * @return bool
	 */
	public function getDomesticExpress9(): bool {
		return $this->domesticExpress9;
	}

	/**
	 * Set availability of Domestic 09 service.
	 *
	 * @param  bool|null $domesticExpress9  Availability of Domestic 09 service.
	 *
	 * @return  self
	 */
	public function setDomesticExpress9( $domesticExpress9 ): self {
		if ( true === $domesticExpress9 ) {
			$this->domesticExpress9 = $domesticExpress9;
		} else {
			$this->domesticExpress9 = false;
		}

		return $this;
	}

	/**
	 * Get availability of Domestic 12 service.
	 *
	 * @return  bool
	 */
	public function getDomesticExpress12(): bool {
		return $this->domesticExpress12;
	}

	/**
	 * Set availability of Domestic 12 service.
	 *
	 * @param  bool|null $domesticExpress12  Availability of Domestic 12 service.
	 *
	 * @return  self
	 */
	public function setDomesticExpress12( $domesticExpress12 ) {
		if ( true === $domesticExpress12 ) {
			$this->domesticExpress12 = $domesticExpress12;
		} else {
			$this->domesticExpress12 = false;
		}

		return $this;
	}

	/**
	 * Get availability of Evening Delivery service.
	 *
	 * @return  bool
	 */
	public function getDeliveryEvening(): bool {
		return $this->deliveryEvening;
	}

	/**
	 * Set availability of Evening Delivery service.
	 *
	 * @param  bool|null $deliveryEvening  Availability of Evening Delivery service.
	 *
	 * @return  self
	 */
	public function setDeliveryEvening( $deliveryEvening ): self {
		if ( true === $deliveryEvening ) {
			$this->deliveryEvening = $deliveryEvening;
		} else {
			$this->deliveryEvening = false;
		}

		return $this;
	}

	/**
	 * Get availability of Saturday Shipment service.
	 *
	 * @return  bool
	 */
	public function getPickupOnSaturday(): bool {
		return $this->pickupOnSaturday;
	}

	/**
	 * Set availability of Saturday Shipment service.
	 *
	 * @param  bool|null $pickupOnSaturday  Availability of Saturday Shipment service.
	 *
	 * @return  self
	 */
	public function setPickupOnSaturday( $pickupOnSaturday ): self {
		if ( true === $pickupOnSaturday ) {
			$this->pickupOnSaturday = $pickupOnSaturday;
		} else {
			$this->pickupOnSaturday = false;
		}

		return $this;
	}

	/**
	 * Get availability of Saturday Delivery service.
	 *
	 * @return  bool
	 */
	public function getDeliverySaturday(): bool {
		return $this->deliverySaturday;
	}

	/**
	 * Set availability of Saturday Delivery service.
	 *
	 * @param  bool|null $deliverySaturday  Availability of Saturday Delivery service.
	 *
	 * @return  self
	 */
	public function setDeliverySaturday( $deliverySaturday ): self {
		if ( true === $deliverySaturday ) {
			$this->deliverySaturday = $deliverySaturday;
		} else {
			$this->deliverySaturday = false;
		}

		return $this;
	}

	/**
	 * Get time from which express shipments can be collected.
	 *
	 * @return  string|null
	 */
	public function getExPickupFrom() {
		return $this->exPickupFrom;
	}

	/**
	 * Set time from which express shipments can be collected.
	 *
	 * @param  string|null $exPickupFrom  Time from which express shipments can be collected.
	 *
	 * @return  self
	 */
	public function setExPickupFrom( $exPickupFrom ) {
		$this->exPickupFrom = $exPickupFrom;

		return $this;
	}

	/**
	 * Get time to which express shipments can be collected.
	 *
	 * @return  string|null
	 */
	public function getExPickupTo() {
		return $this->exPickupTo;
	}

	/**
	 * Set time to which express shipments can be collected.
	 *
	 * @param  string|null $exPickupTo  Time to which express shipments can be collected.
	 *
	 * @return  self
	 */
	public function setExPickupTo( $exPickupTo ) {
		$this->exPickupTo = $exPickupTo;

		return $this;
	}

	/**
	 * Get time from which general shipments can be collected.
	 *
	 * @return  string|null
	 */
	public function getDrPickupFrom() {
		return $this->drPickupFrom;
	}

	/**
	 * Set time from which general shipments can be collected.
	 *
	 * @param  string|null $drPickupFrom  Time from which general shipments can be collected.
	 *
	 * @return  self
	 */
	public function setDrPickupFrom( $drPickupFrom ) {
		$this->drPickupFrom = $drPickupFrom;

		return $this;
	}

	/**
	 * Get time to which general shipments can be collected.
	 *
	 * @return  string|null
	 */
	public function getDrPickupTo() {
		return $this->drPickupTo;
	}

	/**
	 * Set time to which general shipments can be collected.
	 *
	 * @param  string|null $drPickupTo  Time to which general shipments can be collected.
	 *
	 * @return  self
	 */
	public function setDrPickupTo( $drPickupTo ) {
		$this->drPickupTo = $drPickupTo;

		return $this;
	}
}
