<?php
/**
 * Class ReceiverAddress
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * ReceiverAddress
 */
class ReceiverAddress {
	/**
	 * Country code.
	 *
	 * @var string|null
	 */
	private $country;

	/**
	 * Delivery to DHL Parcelstation.
	 *
	 * @var bool|null
	 */
	private $isPackstation;

	/**
	 * Delivery to DHL Parcelshop.
	 *
	 * @var bool|null
	 */
	private $isPostfiliale;

	/**
	 * Customer number - required only for DE with deliveries to parcel lockers.
	 *
	 * @var string|null
	 */
	private $postnummer;

	/**
	 * Address type (B/C).
	 *
	 * @var string|null
	 */
	private $addressType;

	/**
	 * Company name or first name and surname.
	 *
	 * @var string|null
	 */
	private $name;

	/**
	 * Postal code.
	 *
	 * @var string|null
	 */
	private $postalCode;

	/**
	 * City name.
	 *
	 * @var string|null
	 */
	private $city;

	/**
	 * Street.
	 *
	 * @var string|null
	 */
	private $street;

	/**
	 * House number.
	 * In the case of deliveries of international Connect shipments to DHL Parcelstation or DHL Parcelshop - parcelstation or parcelshop number The sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @var string|null
	 */
	private $houseNumber;

	/**
	 * Apartment number.
	 * The sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @var string|null
	 */
	private $apartmentNumber;

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'country'         => $this->getCountry(),
			'isPackstation'   => $this->getIsPackstation(),
			'isPostfiliale'   => $this->getIsPostfiliale(),
			'postnummer'      => $this->getPostnummer(),
			'addressType'     => $this->getAddressType(),
			'name'            => $this->getName(),
			'postalCode'      => $this->getPostalCode(),
			'city'            => $this->getCity(),
			'street'          => $this->getStreet(),
			'houseNumber'     => $this->getHouseNumber(),
			'apartmentNumber' => $this->getApartmentNumber(),
		);
	}

	/**
	 * Get country code.
	 *
	 * @return string|null
	 */
	public function getCountry() {
		return $this->country;
	}

	/**
	 * Set country code.
	 *
	 * @param string|null $country Country code.
	 *
	 * @return self
	 */
	public function setCountry( $country ) {
		$this->country = $country;

		return $this;
	}

	/**
	 * Get delivery to DHL Parcelstation.
	 *
	 * @return bool|null
	 */
	public function getIsPackstation() {
		return $this->isPackstation;
	}

	/**
	 * Set delivery to DHL Parcelstation.
	 *
	 * @param bool|null $isPackstation Delivery to DHL Parcelstation.
	 *
	 * @return self
	 */
	public function setIsPackstation( $isPackstation ) {
		$this->isPackstation = $isPackstation;

		return $this;
	}

	/**
	 * Get delivery to DHL Parcelshop.
	 *
	 * @return bool|null
	 */
	public function getIsPostfiliale() {
		return $this->isPostfiliale;
	}

	/**
	 * Set delivery to DHL Parcelshop.
	 *
	 * @param bool|null $isPostfiliale Delivery to DHL Parcelshop.
	 *
	 * @return self
	 */
	public function setIsPostfiliale( $isPostfiliale ) {
		$this->isPostfiliale = $isPostfiliale;

		return $this;
	}

	/**
	 * Get customer number - required only for DE with deliveries to parcel lockers.
	 *
	 * @return string|null
	 */
	public function getPostnummer() {
		return $this->postnummer;
	}

	/**
	 * Set customer number - required only for DE with deliveries to parcel lockers.
	 *
	 * @param string|null $postnummer Customer number - required only for DE with deliveries to parcel lockers.
	 *
	 * @return self
	 */
	public function setPostnummer( $postnummer ) {
		$this->postnummer = $postnummer;

		return $this;
	}

	/**
	 * Get address type (B/C).
	 *
	 * @return string|null
	 */
	public function getAddressType() {
		return $this->addressType;
	}

	/**
	 * Set address type (B/C).
	 *
	 * @param string|null $addressType Address type (B/C).
	 *
	 * @return self
	 */
	public function setAddressType( $addressType ) {
		$this->addressType = $addressType;

		return $this;
	}

	/**
	 * Get company name or first name and surname.
	 *
	 * @return string|null
	 */
	public function getName() {
		return $this->name;
	}

	/**
	 * Set company name or first name and surname.
	 *
	 * @param string|null $name Company name or first name and surname.
	 *
	 * @return self
	 */
	public function setName( $name ) {
		$this->name = $name;

		return $this;
	}

	/**
	 * Get postal code.
	 *
	 * @return string|null
	 */
	public function getPostalCode() {
		return $this->postalCode;
	}

	/**
	 * Set postal code.
	 *
	 * @param string|null $postalCode Postal code.
	 *
	 * @return self
	 */
	public function setPostalCode( $postalCode ) {
		$this->postalCode = $postalCode;

		return $this;
	}

	/**
	 * Get city name.
	 *
	 * @return string|null
	 */
	public function getCity() {
		return $this->city;
	}

	/**
	 * Set city name.
	 *
	 * @param string|null $city City name.
	 *
	 * @return self
	 */
	public function setCity( $city ) {
		$this->city = $city;

		return $this;
	}

	/**
	 * Get street.
	 *
	 * @return string|null
	 */
	public function getStreet() {
		return $this->street;
	}

	/**
	 * Set street.
	 *
	 * @param string|null $street Street.
	 *
	 * @return self
	 */
	public function setStreet( $street ) {
		$this->street = $street;

		return $this;
	}

	/**
	 * Get in the case of deliveries of international Connect shipments to DHL Parcelstation or DHL Parcelshop - parcelstation or parcelshop number The sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @return string|null
	 */
	public function getHouseNumber() {
		return $this->houseNumber;
	}

	/**
	 * Set in the case of deliveries of international Connect shipments to DHL Parcelstation or DHL Parcelshop - parcelstation or parcelshop number The sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @param string|null $houseNumber In the case of deliveries of international Connect shipments to DHL Parcelstation or DHL Parcelshop - parcelstation or parcelshop number The sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @return self
	 */
	public function setHouseNumber( $houseNumber ) {
		$this->houseNumber = $houseNumber;

		return $this;
	}

	/**
	 * Get the sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @return string|null
	 */
	public function getApartmentNumber() {
		return $this->apartmentNumber;
	}

	/**
	 * Set the sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @param string|null $apartmentNumber The sum of characters in the "apartmentNumber" and "houseNumber" fields shall not exceed 15 characters.
	 *
	 * @return self
	 */
	public function setApartmentNumber( $apartmentNumber ) {
		$this->apartmentNumber = $apartmentNumber;

		return $this;
	}
}
