<?php
/**
 * Class ReturnShipmentTime
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * ReturnShipmentTime
 */
class ReturnShipmentTime {
	/**
	 * Label expiry date.
	 * The minimum validity period of the label is 7 days.
	 *
	 * @var \DateTime
	 */
	private $labelExpDate;

	/**
	 * Constructor
	 */
	public function __construct() {
		$this->labelExpDate = new \DateTime( '7 day' );
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'labelExpDate' => $this->getLabelExpDate()->format( 'Y-m-d' ), // Date in YYYY-MM-DD format.
		);
	}

	/**
	 * Get label expiry date.
	 *
	 * @return  \DateTime
	 */
	public function getLabelExpDate(): \DateTime {
		return $this->labelExpDate;
	}

	/**
	 * Set label expiry date.
	 *
	 * @param  \DateTime $labelExpDate  Label expiry date.
	 * @return  self
	 */
	public function setLabelExpDate( \DateTime $labelExpDate ): self {
		$this->labelExpDate = $labelExpDate;

		return $this;
	}
}
