<?php
/**
 * Class Routing
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * Routing
 */
class Routing {
	/**
	 * Sender depot.
	 *
	 * @var string|null
	 */
	private $senderDepot;

	/**
	 * Destination depot (receiver depot).
	 *
	 * @var string|null
	 */
	private $receiverDepot;

	/**
	 * Which intermediary depots (sorting centers) the shipment will go through on working days.
	 *
	 * @var string|null
	 */
	private $senderAps;

	/**
	 * Which intermediary depots (sorting centers) the shipment will go through on Saturdays.
	 *
	 * @var string|null
	 */
	private $receiverAps;

	/**
	 * Delivery courier route symbol.
	 *
	 * @var string|null
	 */
	private $tourId;

	/**
	 * Get sender depot.
	 *
	 * @return string|null
	 */
	public function getSenderDepot() {
		return $this->senderDepot;
	}

	/**
	 * Set sender depot.
	 *
	 * @param string|null $senderDepot Sender depot.
	 *
	 * @return self
	 */
	public function setSenderDepot( $senderDepot ) {
		$this->senderDepot = $senderDepot;

		return $this;
	}

	/**
	 * Get destination depot (receiver depot).
	 *
	 * @return string|null
	 */
	public function getReceiverDepot() {
		return $this->receiverDepot;
	}

	/**
	 * Set destination depot (receiver depot).
	 *
	 * @param string|null $receiverDepot Destination depot (receiver depot).
	 *
	 * @return self
	 */
	public function setReceiverDepot( $receiverDepot ) {
		$this->receiverDepot = $receiverDepot;

		return $this;
	}

	/**
	 * Get which intermediary depots (sorting centers) the shipment will go through on working days.
	 *
	 * @return string|null
	 */
	public function getSenderAps() {
		return $this->senderAps;
	}

	/**
	 * Set which intermediary depots (sorting centers) the shipment will go through on working days.
	 *
	 * @param string|null $senderAps Which intermediary depots (sorting centers) the shipment will go through on working days.
	 *
	 * @return self
	 */
	public function setSenderAps( $senderAps ) {
		$this->senderAps = $senderAps;

		return $this;
	}

	/**
	 * Get which intermediary depots (sorting centers) the shipment will go through on Saturdays.
	 *
	 * @return string|null
	 */
	public function getReceiverAps() {
		return $this->receiverAps;
	}

	/**
	 * Set which intermediary depots (sorting centers) the shipment will go through on Saturdays.
	 *
	 * @param string|null $receiverAps Which intermediary depots (sorting centers) the shipment will go through on Saturdays.
	 *
	 * @return self
	 */
	public function setReceiverAps( $receiverAps ) {
		$this->receiverAps = $receiverAps;

		return $this;
	}

	/**
	 * Get delivery courier route symbol.
	 *
	 * @return string|null
	 */
	public function getTourId() {
		return $this->tourId;
	}

	/**
	 * Set delivery courier route symbol.
	 *
	 * @param string|null $tourId Delivery courier route symbol.
	 *
	 * @return self
	 */
	public function setTourId( $tourId ) {
		$this->tourId = $tourId;

		return $this;
	}
}
