<?php
/**
 * Class Ship
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * Ship
 */
class Ship {
	/**
	 * Address details of the sender.
	 *
	 * @var Addressat|null
	 */
	private $shipper;

	/**
	 * Address details of the recipient.
	 *
	 * @var ReceiverAddressat|null
	 */
	private $receiver;

	/**
	 * Address details of the neighbour.
	 *
	 * @var NeighbourAddress|null
	 */
	private $neighbour;

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'shipper'   => $this->getShipper() ? $this->getShipper()->toArray() : null,
			'receiver'  => $this->getReceiver() ? $this->getReceiver()->toArray() : null,
			'neighbour' => $this->getNeighbour() ? $this->getNeighbour()->toArray() : null,
		);
	}

	/**
	 * Get address details of the sender.
	 *
	 * @return Addressat|null
	 */
	public function getShipper() {
		return $this->shipper;
	}

	/**
	 * Set address details of the sender.
	 *
	 * @param Addressat|null $shipper Address details of the sender.
	 *
	 * @return self
	 */
	public function setShipper( $shipper ) {
		$this->shipper = $shipper;

		return $this;
	}

	/**
	 * Get address details of the recipient.
	 *
	 * @return ReceiverAddressat|null
	 */
	public function getReceiver() {
		return $this->receiver;
	}

	/**
	 * Set address details of the recipient.
	 *
	 * @param ReceiverAddressat|null $receiver Address details of the recipient.
	 *
	 * @return self
	 */
	public function setReceiver( $receiver ) {
		$this->receiver = $receiver;

		return $this;
	}

	/**
	 * Get address details of the neighbour.
	 *
	 * @return NeighbourAddress|null
	 */
	public function getNeighbour() {
		return $this->neighbour;
	}

	/**
	 * Set address details of the neighbour.
	 *
	 * @param NeighbourAddress|null $neighbour Address details of the neighbour.
	 *
	 * @return self
	 */
	public function setNeighbour( $neighbour ) {
		$this->neighbour = $neighbour;

		return $this;
	}
}
