<?php
/**
 * Class ShipmentOrderInfo
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * ShipmentOrderInfo
 */
class ShipmentOrderInfo {
	/**
	 * Sender details.
	 *
	 * @var Address|null
	 */
	private $shipper;

	/**
	 * Quantity of express shipments.
	 *
	 * @var int
	 */
	private $numberOfExPieces;

	/**
	 * Quantity of general shipments.
	 *
	 * @var int
	 */
	private $numberOfDrPieces;

	/**
	 * Sum weight of the parcels.
	 *
	 * @var int
	 */
	private $totalWeight;

	/**
	 * Weight of the heaviest parcel.
	 *
	 * @var int
	 */
	private $heaviestPieceWeight;

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'shipper'             => $this->getShipper() ? $this->getShipper()->toArray() : null,
			'numberOfExPieces'    => $this->getNumberOfExPieces(),
			'numberOfDrPieces'    => $this->getNumberOfDrPieces(),
			'totalWeight'         => $this->getTotalWeight(),
			'heaviestPieceWeight' => $this->getHeaviestPieceWeight(),
		);
	}

	/**
	 * Get sender details.
	 *
	 * @return Address|null
	 */
	public function getShipper() {
		return $this->shipper;
	}

	/**
	 * Set sender details.
	 *
	 * @param Address|null $shipper Sender details.
	 *
	 * @return self
	 */
	public function setShipper( $shipper ) {
		$this->shipper = $shipper;

		return $this;
	}

	/**
	 * Get quantity of express shipments.
	 *
	 * @return int
	 */
	public function getNumberOfExPieces() {
		return $this->numberOfExPieces;
	}

	/**
	 * Set quantity of express shipments.
	 *
	 * @param int $numberOfExPieces Quantity of express shipments.
	 *
	 * @return self
	 */
	public function setNumberOfExPieces( int $numberOfExPieces ) {
		$this->numberOfExPieces = $numberOfExPieces;

		return $this;
	}

	/**
	 * Get quantity of general shipments.
	 *
	 * @return int
	 */
	public function getNumberOfDrPieces() {
		return $this->numberOfDrPieces;
	}

	/**
	 * Set quantity of general shipments.
	 *
	 * @param int $numberOfDrPieces Quantity of general shipments.
	 *
	 * @return self
	 */
	public function setNumberOfDrPieces( int $numberOfDrPieces ) {
		$this->numberOfDrPieces = $numberOfDrPieces;

		return $this;
	}

	/**
	 * Get sum weight of the parcels.
	 *
	 * @return int
	 */
	public function getTotalWeight() {
		return $this->totalWeight;
	}

	/**
	 * Set sum weight of the parcels.
	 *
	 * @param int $totalWeight Sum weight of the parcels.
	 *
	 * @return self
	 */
	public function setTotalWeight( int $totalWeight ) {
		$this->totalWeight = $totalWeight;

		return $this;
	}

	/**
	 * Get weight of the heaviest parcel.
	 *
	 * @return int
	 */
	public function getHeaviestPieceWeight() {
		return $this->heaviestPieceWeight;
	}

	/**
	 * Set weight of the heaviest parcel.
	 *
	 * @param int $heaviestPieceWeight Weight of the heaviest parcel.
	 *
	 * @return self
	 */
	public function setHeaviestPieceWeight( int $heaviestPieceWeight ) {
		$this->heaviestPieceWeight = $heaviestPieceWeight;

		return $this;
	}
}
