<?php
/**
 * Class WebAPIClient
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI;

use InvalidArgumentException;
use ILabs\WoocommerceDHL24\DHL24Client\SoapClient;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Method;
use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Convert\ConvertInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Convert\ConvertContext;

/**
 * WebAPIClient
 */
class WebAPIClient extends SoapClient {


	/**
	 * Return Version.
	 *
	 * @param Method\GetVersion $parameters Function parameters.
	 * @return Type\GetVersionResponse
	 * @throws \Exception If error.
	 */
	public function getVersion( Method\GetVersion $parameters ): Type\Version {
		$this->method = 'getVersion';
		return $this->call( $parameters );
	}

	/**
	 * Return ShipmentBasicDatas.
	 *
	 * @param Method\CreateShipments $parameters Function parameters.
	 * @return Type\ShipmentBasicDatas
	 * @throws \Exception If error.
	 */
	public function createShipments( Method\CreateShipments $parameters ) : Type\ShipmentBasicDatas {
		$this->method = 'createShipments';
		return $this->call( $parameters );
	}

	/**
	 * Return Shipments.
	 *
	 * @param Method\GetReturnByWaybill $parameters Function parameters.
	 * @return Type\Shipments
	 * @throws \Exception If error.
	 */
	public function getReturnByWaybill( Method\GetReturnByWaybill $parameters ) : Type\Shipments {
		$this->method = 'getReturnByWaybill';
		return $this->call( $parameters );
	}

	/**
	 * Return Shipment.
	 *
	 * @param Method\CreateShipmentReturn $parameters Function parameters.
	 * @return Type\ReturnShipments
	 * @throws \Exception If error.
	 */
	public function createShipmentReturn( Method\CreateShipmentReturn $parameters ) : Type\ReturnShipments {
		$this->method = 'createShipmentReturn';
		return $this->call( $parameters );
	}

	/**
	 * Return DeleteNotifications.
	 *
	 * @param Method\DeleteShipments $parameters Function parameters.
	 * @return Type\DeleteNotifications
	 * @throws \Exception If error.
	 */
	public function deleteShipments( Method\DeleteShipments $parameters ) : Type\DeleteNotifications {
		$this->method = 'deleteShipments';
		return $this->call( $parameters );
	}

	/**
	 * Return ShipmentBasicDatas.
	 *
	 * @param Method\GetMyShipments $parameters Function parameters.
	 * @return Type\ShipmentBasicDatas
	 * @throws \Exception If error.
	 */
	public function getMyShipments( Method\GetMyShipments $parameters ) : Type\ShipmentBasicDatas {
		$this->method = 'getMyShipments';
		return $this->call( $parameters );
	}

	/**
	 * Return ShipmentsCount.
	 *
	 * @param Method\GetMyShipmentsCount $parameters Function parameters.
	 * @return Type\ShipmentsCount
	 * @throws \Exception If error.
	 */
	public function getMyShipmentsCount( Method\GetMyShipmentsCount $parameters ) : Type\ShipmentsCount {
		$this->method = 'getMyShipmentsCount';
		return $this->call( $parameters );
	}

	/**
	 * Return PostalCodeServices.
	 *
	 * @param Method\GetPostalCodeServices $parameters Function parameters.
	 * @return Type\PostalCodeServices
	 * @throws \Exception If error.
	 */
	public function getPostalCodeServices( Method\GetPostalCodeServices $parameters ) : Type\PostalCodeServices {
		$this->method = 'getPostalCodeServices';
		return $this->call( $parameters );
	}

	/**
	 * Return TrackAndTrace.
	 *
	 * @param Method\GetTrackAndTraceInfo $parameters Function parameters.
	 * @return Type\TrackAndTrace
	 * @throws \Exception If error.
	 */
	public function getTrackAndTraceInfo( Method\GetTrackAndTraceInfo $parameters ) : Type\TrackAndTrace {
		$this->method = 'getTrackAndTraceInfo';
		return $this->call( $parameters );
	}

	/**
	 * Return Strings.
	 *
	 * @param Method\BookCourier $parameters Function parameters.
	 * @return Type\Strings
	 * @throws \Exception If error.
	 */
	public function bookCourier( Method\BookCourier $parameters ) : Type\Strings {
		$this->method = 'bookCourier';
		return $this->call( $parameters );
	}

	/**
	 * Return DeleteNotifications.
	 *
	 * @param Method\CancelCourierBooking $parameters Function parameters.
	 * @return Type\DeleteNotifications
	 * @throws \Exception If error.
	 */
	public function cancelCourierBooking( Method\CancelCourierBooking $parameters ) : Type\DeleteNotifications {
		$this->method = 'cancelCourierBooking';
		return $this->call( $parameters );
	}

	/**
	 * Return Labels.
	 *
	 * @param Method\GetLabels $parameters Function parameters.
	 * @return Type\Labels
	 * @throws \Exception If error.
	 */
	public function getLabels( Method\GetLabels $parameters ) : Type\Labels {
		$this->method = 'getLabels';
		return $this->call( $parameters );
	}

	/**
	 * Return Pnp.
	 *
	 * @param Method\GetPnp $parameters Function parameters.
	 * @return Type\Pnp
	 * @throws \Exception If error.
	 */
	public function getPnp( Method\GetPnp $parameters ) : Type\Pnp {
		$this->method = 'getPnp';
		return $this->call( $parameters );
	}

	/**
	 * Return ScanToPrint.
	 *
	 * @param Method\GetShipmentScan $parameters Function parameters.
	 * @return Type\ScanToPrint
	 * @throws \Exception If error.
	 */
	public function getShipmentScan( Method\GetShipmentScan $parameters ) : Type\ScanToPrint {
		$this->method = 'getShipmentScan';
		return $this->call( $parameters );
	}

	/**
	 * Return Shipment.
	 *
	 * @param Method\CreateShipment $parameters Function parameters.
	 * @return Type\Shipment
	 * @throws \Exception If error.
	 */
	public function createShipment( Method\CreateShipment $parameters ) : Type\Shipment {
		$this->method = 'createShipment';
		return $this->call( $parameters );
	}

	/**
	 * Return DeleteShipment.
	 *
	 * @param Method\DeleteShipment $parameters Function parameters.
	 * @return Type\DeleteShipment
	 * @throws \Exception If error.
	 */
	public function deleteShipment( Method\DeleteShipment $parameters ) : Type\DeleteShipment {
		$this->method = 'deleteShipment';
		return $this->call( $parameters );
	}

	/**
	 * Return NearestServicepoints.
	 *
	 * @param Method\GetNearestServicepoints $parameters Function parameters.
	 * @return Type\NearestServicepoints
	 * @throws \Exception If error.
	 */
	public function getNearestServicepoints( Method\GetNearestServicepoints $parameters ) : Type\NearestServicepoints {
		$this->method = 'getNearestServicepoints';
		return $this->call( $parameters );
	}

	/**
	 * Return InternationalParams.
	 *
	 * @param Method\GetInternationalParams $parameters Function parameters.
	 * @throws \Exception If error.
	 * @return Type\InternationalParams
	 */
	public function getInternationalParams( Method\GetInternationalParams $parameters ) : Type\InternationalParams {
		$this->method = 'getInternationalParams';
		return $this->call( $parameters );
	}

	/**
	 * Return ReturnParams.
	 *
	 * @param Method\GetReturnParams $parameters Function parameters.
	 * @return Type\GetReturnParamsResponse
	 * @throws \Exception If error.
	 */
	public function getReturnParams( Method\GetReturnParams $parameters ) : Type\ReturnParams {
		$this->method = 'getReturnParams';
		return $this->call( $parameters );
	}

	/**
	 * Return InternationalParams2.
	 *
	 * @param Method\GetInternationalParams2 $parameters Function parameters.
	 * @return Type\GetInternationalParams2Response
	 * @throws \Exception If error.
	 */
	public function getInternationalParams2( Method\GetInternationalParams2 $parameters ) : Type\InternationalParams2 {
		$this->method = 'getInternationalParams2';
		return $this->call( $parameters );
	}

	/**
	 * Return PieceShipments.
	 *
	 * @param Method\GetPieceId $parameters Function parameters.
	 * @return Type\PieceShipments
	 * @throws \Exception If error.
	 */
	public function getPieceId( Method\GetPieceId $parameters ) : Type\PieceShipments {
		$this->method = 'getPieceId';
		return $this->call( $parameters );
	}

	/**
	 * Return LabelsDatas.
	 *
	 * @param Method\GetLabelsData $parameters Function parameters.
	 * @return Type\LabelsDatas
	 * @throws \Exception If error.
	 */
	public function getLabelsData( Method\GetLabelsData $parameters ) : Type\LabelsDatas {
		$this->method = 'getLabelsData';
		return $this->call( $parameters );
	}

	/**
	 * { @inheritDoc }
	 *
	 * @param \stdClass $sourceObject Source object.
	 *
	 * @return ResultInterface Result.
	 */
	protected function cast( \stdClass $sourceObject ): ResultInterface {
		$context = new ConvertContext();
		$context->setStrategy( $this->getStrategy() );
		return $context->cast( $sourceObject );
	}

	/**
	 * Get strategy.
	 *
	 * @throws \InvalidArgumentException If error.
	 * @return ConvertInterface
	 */
	private function getStrategy() : ConvertInterface {
		$strategyClassName = __NAMESPACE__ . '\\Convert\\Convert' . \ucfirst( $this->method );
		try {
			return new $strategyClassName();
		} catch ( \Exception $e ) {
			throw new \InvalidArgumentException();
		}
	}
}
