<?php
/**
 * Class Comparator.
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\Helper;

use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\ShipmentTimeLabel;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\ShipperAddressLabel;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\LabelDataServiceDefinition;

/**
 * Comparator
 */
class Comparator {


	/**
	 * Pattern shipper
	 *
	 * @var ShipperAddressLabel|null
	 */
	private $pattern_shipper;

	/**
	 * Pattern shipment time
	 *
	 * @var ShipmentTimeLabel|null
	 */
	private $pattern_shipment_time;

	/**
	 * Individual quantity
	 *
	 * @var int
	 */
	private $individual_quantity = 0;

	/**
	 * Reset patterns
	 *
	 * @return void
	 */
	public function reset_patterns() {
		$this->pattern_shipment_time = null;
		$this->pattern_shipper       = null;
		$this->individual_quantity   = 0;
	}

	/**
	 * Is the same place of shipper address
	 *
	 * @param  ShipperAddressLabel|null $shipper Sender address details.
	 * @return bool
	 */
	public function is_the_same_shipper( $shipper ): bool {
		if ( ! $shipper instanceof ShipperAddressLabel ) {
			return false;
		}

		if ( null === $this->pattern_shipper ) {
			$this->pattern_shipper = $shipper;
			return true;
		}

		$source_reflection = new \ReflectionObject( $shipper );
		$source_properties = $source_reflection->getProperties();
		foreach ( $source_properties as $source_property ) {
			$get_method = 'get' . \ucfirst( $source_property->getName() );
			if ( $this->pattern_shipper->$get_method() !== $shipper->$get_method() ) {
				return false;
			}
		}

		return true;
	}

	/**
	 * Is the same posting date
	 *
	 * @param  ShipmentTimeLabel|null $shipment_time The parcel shipment time.
	 * @return bool
	 */
	public function is_the_same_posting_date( $shipment_time ): bool {
		if ( ! $shipment_time instanceof ShipmentTimeLabel ) {
			return false;
		}

		if ( null === $this->pattern_shipment_time ) {
			$this->pattern_shipment_time = $shipment_time;
			return true;
		}

		if ( $this->pattern_shipment_time->getShipmentDate() !== $shipment_time->getShipmentDate() ) {
			return false;
		}

		return true;
	}

	/**
	 * Is courier ordered individually
	 *
	 * @param  LabelDataServiceDefinition $service Shipping and additional services.
	 * @return bool
	 */
	public function is_courier_ordered_individually( $service ): bool {
		if ( ! $service instanceof LabelDataServiceDefinition ) {
			return false;
		}

		$service_type = $service->getProduct();
		if ( in_array( $service_type, array( 'ZK', 'ZC' ), true ) ) {
			$this->individual_quantity++;
			if ( 1 < $this->individual_quantity ) {
				return false;
			}
		}
		return true;
	}
}
