<?php
/**
 * Class NearestService.
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\Helper;

use ILabs\WoocommerceDHL24\Exception\ExceptionInterface;
use ILabs\WoocommerceDHL24\Repository\ShipmentsRepository;
use ILabs\WoocommerceDHL24\Repository\ServicePointRepository;
use ILabs\WoocommerceDHL24\DHL24Client\ServicePoint as ServicePoint;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI as WebAPI;


/**
 * NearestService
 */
class NearestService {

	/**
	 * Shipping method
	 *
	 * @var string
	 */
	private $shipping_method;

	/**
	 * Shipping postcode
	 *
	 * @var mixed
	 */
	private $postcode;

	/**
	 * Shipping country
	 *
	 * @var mixed
	 */
	private $country;

	/**
	 * __construct
	 *
	 * @param  string $shipping_method Shipping method.
	 * @param  string $postcode Shipping postcode.
	 * @param  string $country Shipping country.
	 * @return void
	 */
	public function __construct( string $shipping_method, string $postcode, string $country ) {
		$this->shipping_method = $shipping_method;
		$this->postcode        = $postcode;
		$this->country         = $country;
	}

	/**
	 * Get point
	 *
	 * @return ServicePoint\Type\Point|WebAPI\Type\Point
	 */
	public function get_point() {
		$point = new ServicePoint\Type\Point();
		if ( in_array( $this->shipping_method, array( 'dhl24_service_sp', 'dhl24_service_lm' ), true ) ) {
			$service_point_repository = new ServicePointRepository();
			$nearest_service_points   = null;
			try {
				$nearest_service_points = $service_point_repository->fetch_nearest_service_points( $this->postcode, 100 );
			} catch ( ExceptionInterface $e ) {
				wc_add_notice( $e->getMessage(), 'error' );
				$nearest_service_points = new ServicePoint\Type\NearestServicepoints();
			}

			if ( $nearest_service_points instanceof ServicePoint\Type\NearestServicepoints && 0 < $nearest_service_points->getCount() ) {
				$point = $nearest_service_points->getPoints()->offsetGet( 0 );
			}
		} elseif ( '_TODO_zagranica_' === $this->shipping_method ) {
			$shipments_repository   = new ShipmentsRepository();
			$nearest_service_points = null;
			try {
				$nearest_service_points = $shipments_repository->fetch_nearest_service_points( $this->postcode, $this->country, 25 );
			} catch ( ExceptionInterface $e ) {
				wc_add_notice( $e->getMessage(), 'error' );
				$nearest_service_points = new WebAPI\Type\NearestServicepoints();
			}

			if ( $nearest_service_points instanceof WebAPI\Type\NearestServicepoints && 0 < $nearest_service_points->getCount() ) {
				$point = $nearest_service_points->getPoints()->offsetGet( 0 );
			}
		}

		return $point;
	}
}
