<?php
/**
 * Class Normalizer.
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\Helper;

use ILabs\WoocommerceDHL24\Helper\Param;

/**
 * Normalizer
 */
class Normalizer {
	/**
	 * Normalize date
	 *
	 * @param  mixed $datetime Value.
	 * @return \DateTime|null
	 */
	public function date( $datetime ) {
		$datetime = sanitize_text_field( $datetime );
		if ( '' !== $datetime ) {
			$date = \DateTime::createFromFormat( 'Y-m-d', $datetime );
			if ( false !== $date ) {
				return $date;
			}
		}

		return null;
	}

	/**
	 * Normalize hour
	 *
	 * @param  mixed $hour Value.
	 * @return string
	 */
	public function hour( $hour ) {
		$hour = sanitize_text_field( $hour );
		if ( '' !== $hour ) {
			$date = \DateTime::createFromFormat( 'H:i', $hour );
			if ( false !== $date ) {
				return $date->format( 'H:i' );
			}
		}

		return $hour;
	}

	/**
	 * Normalize integer
	 *
	 * @param  mixed $value Value.
	 * @return int
	 */
	public function integer( $value ): int {
		$value = sanitize_text_field( $value );

		return (int) $value;
	}

	/**
	 * Normalize float
	 *
	 * @param  mixed $value Value.
	 * @return float
	 */
	public function float( $value ): float {
		$value = sanitize_text_field( $value );
		$value = str_replace( array( ' ', ',' ), array( '', '.' ), $value );

		return (float) $value;
	}

	/**
	 * Normalize bool
	 *
	 * @param  mixed $value Value.
	 * @return bool
	 */
	public function bool( $value ): bool {
		$value = sanitize_text_field( $value );
		if ( \in_array( $value, array( 'true', '1' ), true ) ) {
			return true;
		}

		return false;
	}

	/**
	 * Normalize piece type
	 *
	 * @param  mixed $value Value.
	 * @return string|null
	 */
	public function piece_type( $value ) {
		$value        = sanitize_text_field( $value );
		$parcel_types = Param::get_instance()->get_value( 'parcel_types' );
		$parcel_types = array_keys( $parcel_types );
		if ( \in_array( $value, $parcel_types, true ) ) {
			return $value;
		}

		return null;
	}

	/**
	 * Shipping method
	 *
	 * @param  string $value Value.
	 * @return string
	 */
	public function shipping_method( string $value ): string {
		$value = explode( ':', $value );

		return $value[0];
	}
}
