<?php
/**
 * Class Notice.
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\Helper;

/**
 * Notice
 */
class Notice {

	/**
	 * Instance
	 *
	 * @var self|null
	 */
	private static $instance = null;

	/**
	 * Notices
	 *
	 * @var array
	 */
	private $notices = array();

	/**
	 * Construct
	 *
	 * @return void
	 */
	private function __construct() {
		$this->notices = array();
		add_action( 'dhl24_notices', array( $this, 'show' ) );
	}

	/**
	 * Get instance
	 *
	 * @return self
	 */
	public static function get_instance(): self {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}


	/**
	 * Get notices
	 *
	 * @return  array
	 */
	public function get_notices(): array {
		return $this->notices;
	}

	/**
	 * Add notice
	 *
	 * @param string $type Message type.
	 * @param string $message Message.
	 * @return void
	 */
	public function add( string $type, string $message ) {
		if ( ! in_array( $type, array( 'error', 'warning', 'success' ), true ) ) {
			$type = 'info ';
		}

		$this->notices[] = array(
			'type'    => $type,
			'message' => $message,
		);
	}

	/**
	 * Show
	 *
	 * @return void
	 */
	public function show() {
		foreach ( $this->get_notices() as $notice ) {
			printf( '<div class="notice notice-%1$s"><p>%2$s</p></div>', esc_attr( $notice['type'] ), esc_html( $notice['message'] ) );
		}

	}
}
