<?php
/**
 * Class Pieces.
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\Helper;

use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\PieceDefinitionLabel;

/**
 * Pieces
 */
class Pieces {
	/**
	 * List of shipment parcel data.
	 *
	 * @var \ArrayObject|PieceDefinitionLabel[]
	 */
	private $piece_list;

	/**
	 * Construct
	 *
	 * @return void
	 */
	public function __construct() {
		$this->piece_list = new \ArrayObject();
	}

	/**
	 * Add list of shipment parcel data.
	 *
	 * @param  \ArrayObject|PieceDefinitionLabel[] $piece_list  List of shipment parcel data.
	 *
	 * @return  self
	 */
	public function add_piece_list( $piece_list ) {
		foreach ( $piece_list as $piece_item ) {
			$this->piece_list->append( $piece_item );
		}

		return $this;
	}

	/**
	 * Get totals.
	 *
	 * @return array
	 */
	public function get_totals(): array {
		$totals = array(
			'ENVELOPE' => 0,
			'PACKAGE'  => 0,
			'PALLET'   => 0,
			'weight'   => 0,
		);

		foreach ( $this->piece_list as $piece_item ) {
			$piece_type = $piece_item->getType();
			if ( 50 < $piece_item->getWeight() && 'PACKAGE' === $piece_type ) {
				$piece_type = 'PALLET';
			}
			if ( ! isset( $totals[ $piece_type ] ) ) {
				$totals[ $piece_type ] = 0;
			}
			$totals[ $piece_type ] += $piece_item->getQuantity();
			$totals['weight']      += $piece_item->getWeight();
		}

		return $totals;
	}

	/**
	 * Is drPickup
	 *
	 * @return bool
	 */
	public function is_dr_pickup(): bool {
		foreach ( $this->piece_list as $piece_item ) {
			if ( 31.5 < $piece_item->getWeight() ) {
				return true;
			}
			if ( 50 > $piece_item->getWeight() && ( 200 < $piece_item->getLength() || 200 < $piece_item->getWidth() || 200 < $piece_item->getHeight() ) ) {
				return true;
			}
		}

		return false;
	}
}
