<?php
/**
 * Class Template.
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\Helper;

/**
 * Template
 */
class Template {

	/**
	 * Instance
	 *
	 * @var self|null
	 */
	private static $instance = null;

	/**
	 * Option name
	 *
	 * @var string
	 */
	private $option_name;

	/**
	 * Data
	 *
	 * @var array
	 */
	private $data;


	/**
	 * Construct
	 *
	 * @return void
	 */
	private function __construct() {
		$this->option_name = Defaults::OPTION_NAME . '_templates';
		// Fetch existing templates.
		$this->data = get_option( $this->option_name, array() );
		ksort( $this->data );
	}

	/**
	 * Get instance
	 *
	 * @return self
	 */
	public static function get_instance(): self {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}


	/**
	 * Get data
	 *
	 * @return  array
	 */
	public function get_data(): array {
		return $this->data;
	}

	/**
	 * Get value of template ID
	 *
	 * @param  string $template_id Template ID.
	 * @return array
	 */
	public function get_value( string $template_id ): array {
		if ( isset( $this->data[ $template_id ] ) ) {
			return $this->data[ $template_id ];
		}

		return array();
	}

	/**
	 * Get templates
	 *
	 * @param  bool $add_nonce Add nonce.
	 * @return array
	 */
	public function get_templates( bool $add_nonce = false ): array {
		$output = array();
		foreach ( $this->data as $key => $value ) {
			$data       = $this->set_data( $value );
			$data['id'] = $key;

			if ( true === $add_nonce ) {
				$data['_nonce'] = wp_create_nonce( 'ajax_shipment_template_delete_' . $key );
			}

			$output[] = $data;
		}

		return $output;
	}

	/**
	 * Save template data
	 *
	 * @param  array $data Template data.
	 * @return void
	 */
	public function save( array $data ) {
		if ( empty( $data['id'] ) ) {
			$data['id'] = (int) $this->array_key_last( $this->data ) + 1;
		}
		$this->data[ $data['id'] ] = $this->set_data( $data );

		update_option( $this->option_name, $this->data );
	}

	/**
	 * Delete template
	 *
	 * @param  string $id Template ID.
	 * @return void
	 */
	public function delete( string $id ) {
		if ( ! empty( $id ) ) {
			unset( $this->data[ $id ] );

			update_option( $this->option_name, $this->data );
		}
	}

	/**
	 * Gets the last key of an array
	 * For PHP <= 7.3.0
	 *
	 * @param  mixed $array An array.
	 * @return mixed
	 */
	private function array_key_last( $array ) {
		if ( ! is_array( $array ) || empty( $array ) ) {
			return null;
		}

		return array_keys( $array )[ count( $array ) - 1 ];
	}

	/**
	 * Set data
	 *
	 * @param  array $value Values.
	 * @return array
	 */
	private function set_data( array $value ): array {
		$data = array(
			'name'                           => null,
			'piece_quantity'                 => null,
			'piece_type'                     => null,
			'piece_weight'                   => null,
			'piece_width'                    => null,
			'piece_height'                   => null,
			'piece_length'                   => null,
			'piece_nonStandard'              => null,
			'piece_euroReturn'               => null,
			'content'                        => null,
			'comment'                        => null,
			'reference'                      => null,
			'costs_center'                   => null,
			'service_insurance'              => null,
			'service_insurance_value'        => null,
			'service_predeliveryInformation' => null,
		);
		foreach ( $data as $key => $v ) {
			if ( isset( $value[ $key ] ) ) {
				$data[ $key ] = $value[ $key ];
			}
		}

		return $data;
	}
}
