<?php
/**
 * Class WooCommerceSettingsDHL24.
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\Helper;

use WC_Settings_Page;

/**
 * WooCommerceSettingsDHL24
 */
class WooCommerceSettingsDHL24 extends WC_Settings_Page {
	/**
	 * Constructor.
	 *
	 * @param string $id Page settings id.
	 */
	public function __construct( string $id ) {
		$this->id    = $id;
		$this->label = __( 'DHL 24', 'woocommerce-dhl24' );

		parent::__construct();
	}

	/**
	 * Get settings for the default section.
	 *
	 * @return array
	 */
	protected function get_settings_for_default_section() {
		// Default options.
		$default = Defaults::get_values();

		$settings =
			array(
				array(
					'title' => __( 'DHL24 WebAPI', 'woocommerce-dhl24' ),
					'desc'  => __( 'DHL24 WebAPI is a web service that enables the exchange of information between the DHL24 portal and external software of our customers.', 'woocommerce-dhl24' ),
					'type'  => 'title',
					'id'    => 'dhl24_webapi_options',
				),
				array(
					'title'    => __( 'WSDL', 'woocommerce-dhl24' ),
					'desc'     => __( 'The type of environment.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[webapi_wsdl]',
					'type'     => 'select',
					'options'  => array(
						esc_attr( 'https://sandbox.dhl24.com.pl/webapi2' ) => __( 'Sandbox', 'woocommerce-dhl24' ),
						esc_attr( 'https://dhl24.com.pl/webapi2' ) => __( 'Production', 'woocommerce-dhl24' ),
					),
					'default'  => $default['webapi_wsdl'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Username', 'woocommerce-dhl24' ),
					'desc'     => __( 'Received user key.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[webapi_username]',
					'type'     => 'text',
					'default'  => $default['webapi_username'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Password', 'woocommerce-dhl24' ),
					'desc'     => __( 'Assigned password.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[webapi_password]',
					'type'     => 'text',
					'default'  => '',
					'desc_tip' => true,
				),
				array(
					'type' => 'sectionend',
					'id'   => 'dhl24_webapi_options',
				),
				array(
					'title' => __( 'DHL24 Parcelshop Manager WebAPI', 'woocommerce-dhl24' ),
					'desc'  => __( 'DHL24 WebAPI is a web service that enables the exchange of information between the DHL24 portal and external software of our customers.', 'woocommerce-dhl24' ),
					'type'  => 'title',
					'id'    => 'dhl24_servicepoint_options',
				),
				array(
					'title'    => __( 'WSDL', 'woocommerce-dhl24' ),
					'desc'     => __( 'The type of environment.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[servicepoint_wsdl]',
					'type'     => 'select',
					'options'  => array(
						esc_attr( 'https://sandbox.dhl24.com.pl/servicepoint' ) => __( 'Sandbox', 'woocommerce-dhl24' ),
						esc_attr( 'https://dhl24.com.pl/servicepoint' ) => __( 'Production', 'woocommerce-dhl24' ),
					),
					'default'  => $default['servicepoint_wsdl'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Username', 'woocommerce-dhl24' ),
					'desc'     => __( 'Received user key.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[servicepoint_username]',
					'type'     => 'text',
					'default'  => $default['servicepoint_username'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Password', 'woocommerce-dhl24' ),
					'desc'     => __( 'Assigned password.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[servicepoint_password]',
					'type'     => 'text',
					'default'  => '',
					'desc_tip' => true,
				),
				array(
					'type' => 'sectionend',
					'id'   => 'dhl24_servicepoint_options',
				),
				array(
					'title' => __( 'Shipping package parameters', 'woocommerce-dhl24' ),
					'type'  => 'title',
					'id'    => 'dhl24_shipping_package',
				),
				array(
					'title'    => __( 'SAP', 'woocommerce-dhl24' ),
					'desc'     => __( "Payer's customer number (SAP)", 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[sap]',
					'type'     => 'text',
					'default'  => $default['sap'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Name', 'woocommerce-dhl24' ),
					'desc'     => __( 'Company name or first name and surname.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[name]',
					'type'     => 'text',
					'default'  => $default['name'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Country', 'woocommerce-dhl24' ),
					'desc'     => __( 'Country', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[country]',
					'type'     => 'select',
					'options'  => WC()->countries->get_shipping_countries(),
					'default'  => $default['country'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Postal code', 'woocommerce-dhl24' ),
					'desc'     => __( 'Postal code', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[postal_code]',
					'type'     => 'text',
					'default'  => $default['postal_code'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'City', 'woocommerce-dhl24' ),
					'desc'     => __( 'City', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[city]',
					'type'     => 'text',
					'default'  => $default['city'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Street', 'woocommerce-dhl24' ),
					'desc'     => __( 'Street', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[street]',
					'type'     => 'text',
					'default'  => $default['street'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'House number', 'woocommerce-dhl24' ),
					'desc'     => __( 'The sum of characters in the "Apartment nmber" and "House number" fields shall not exceed 15 characters.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[house_nmber]',
					'type'     => 'text',
					'default'  => $default['house_nmber'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Apartment number', 'woocommerce-dhl24' ),
					'desc'     => __( 'The sum of characters in the "Apartment nmber" and "House number" fields shall not exceed 15 characters.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[apartment_number]',
					'type'     => 'text',
					'default'  => $default['apartment_number'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Contact person', 'woocommerce-dhl24' ),
					'desc'     => __( 'Name and surname of the contact person.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[contact_person]',
					'type'     => 'text',
					'default'  => $default['contact_person'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Contact phone', 'woocommerce-dhl24' ),
					'desc'     => __( 'Phone number of the contact person.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[contact_phone]',
					'type'     => 'text',
					'default'  => $default['contact_phone'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Contact email', 'woocommerce-dhl24' ),
					'desc'     => __( 'Email of the contact person.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[contact_email]',
					'type'     => 'text',
					'default'  => $default['contact_email'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Auto create shipment', 'woocommerce-dhl24' ),
					'desc'     => __( 'Automatic creation of a shipment during the order.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[auto_create]',
					'type'     => 'checkbox',
					'default'  => $default['auto_create'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Auto order a courier', 'woocommerce-dhl24' ),
					'desc'     => __( 'Automatic courier ordering during the order.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[auto_order_courier]',
					'type'     => 'checkbox',
					'default'  => $default['auto_order_courier'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Shipment start hour', 'woocommerce-dhl24' ),
					'desc'     => __( 'Time from which the shipment is ready to be collected.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[shipment_start_hour]',
					'type'     => 'text',
					'default'  => $default['shipment_start_hour'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Shipment end hour', 'woocommerce-dhl24' ),
					'desc'     => __( 'Time until which the shipment can be collected.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[shipment_end_hour]',
					'type'     => 'text',
					'default'  => $default['shipment_end_hour'],
					'desc_tip' => true,
				),
				array(
					'type' => 'sectionend',
					'id'   => 'dhl24_shipping_package',
				),
				array(
					'title' => __( 'Return package parameters', 'woocommerce-dhl24' ),
					'type'  => 'title',
					'id'    => 'dhl24_return_package',
				),
				array(
					'title'    => __( 'SAP', 'woocommerce-dhl24' ),
					'desc'     => __( "Payer's customer number (SAP)", 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[return_sap]',
					'type'     => 'text',
					'default'  => $default['return_sap'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Name', 'woocommerce-dhl24' ),
					'desc'     => __( 'Company name or first name and surname.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[return_name]',
					'type'     => 'text',
					'default'  => $default['return_name'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Country', 'woocommerce-dhl24' ),
					'desc'     => __( 'Country', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[return_country]',
					'type'     => 'select',
					'options'  => WC()->countries->get_shipping_countries(),
					'default'  => $default['return_country'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Postal code', 'woocommerce-dhl24' ),
					'desc'     => __( 'Postal code', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[return_postal_code]',
					'type'     => 'text',
					'default'  => $default['return_postal_code'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'City', 'woocommerce-dhl24' ),
					'desc'     => __( 'City', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[return_city]',
					'type'     => 'text',
					'default'  => $default['return_city'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Street', 'woocommerce-dhl24' ),
					'desc'     => __( 'Street', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[return_street]',
					'type'     => 'text',
					'default'  => $default['return_street'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'House number', 'woocommerce-dhl24' ),
					'desc'     => __( 'The sum of characters in the "Apartment nmber" and "House number" fields shall not exceed 15 characters.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[return_house_nmber]',
					'type'     => 'text',
					'default'  => $default['return_house_nmber'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Apartment number', 'woocommerce-dhl24' ),
					'desc'     => __( 'The sum of characters in the "Apartment nmber" and "House number" fields shall not exceed 15 characters.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[return_apartment_number]',
					'type'     => 'text',
					'default'  => $default['return_apartment_number'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Contact person', 'woocommerce-dhl24' ),
					'desc'     => __( 'Name and surname of the contact person.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[return_contact_person]',
					'type'     => 'text',
					'default'  => $default['return_contact_person'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Contact phone', 'woocommerce-dhl24' ),
					'desc'     => __( 'Phone number of the contact person.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[return_contact_phone]',
					'type'     => 'text',
					'default'  => $default['return_contact_phone'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Contact email', 'woocommerce-dhl24' ),
					'desc'     => __( 'Email of the contact person.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[return_contact_email]',
					'type'     => 'text',
					'default'  => $default['return_contact_email'],
					'desc_tip' => true,
				),
				array(
					'title'             => __( 'Label expiration', 'woocommerce-dhl24' ),
					'desc'              => __( 'Expiry days of the domestic return label. The minimum validity period of the label is 7 days.', 'woocommerce-dhl24' ),
					'id'                => Defaults::OPTION_NAME . '[return_label_exp]',
					'type'              => 'number',
					'custom_attributes' => array(
						'min'  => 7,
						'max'  => 183,
						'step' => 1,
					),
					'default'           => $default['return_label_exp'],
					'desc_tip'          => true,
				),
				array(
					'title'    => __( 'The possibility of sending a return shipment by courier', 'woocommerce-dhl24' ),
					'desc'     => __( 'The service only applies to domestic shipments up to 31.5 kg. Checking will allow the sender to order a courier to collect the parcel. If this option is not selected, the sender will be able to send the shipment only at a DHL Parcel point.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[return_order_courier]',
					'type'     => 'checkbox',
					'default'  => $default['return_order_courier'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Auto create return shipment', 'woocommerce-dhl24' ),
					'desc'     => __( 'Automatic creation of a return shipment during the order.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[return_auto_create]',
					'type'     => 'checkbox',
					'default'  => $default['return_auto_create'],
					'desc_tip' => true,
				),
				array(
					'type' => 'sectionend',
					'id'   => 'dhl24_return_package',
				),
				array(
					'title' => __( 'Common parameters', 'woocommerce-dhl24' ),
					'type'  => 'title',
					'id'    => 'dhl24_common',
				),
				array(
					'name'     => __( 'Label type', 'woocommerce-dhl24' ),
					'desc'     => __( 'Default Label type.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[label_type]',
					'type'     => 'select',
					'options'  => array(
						'BLP'  => __( 'BLP label in PDF format', 'woocommerce-dhl24' ),
						'LBLP' => __( 'BLP label in PDF A4 format', 'woocommerce-dhl24' ),
						'ZBLP' => __( 'BLP label in the ZPL format', 'woocommerce-dhl24' ),
					),
					'default'  => $default['label_type'],
					'desc_tip' => true,
				),
				array(
					'type' => 'sectionend',
					'id'   => 'dhl24_common',
				),
				array(
					'title' => __( 'Parcel parameters', 'woocommerce-dhl24' ),
					'type'  => 'title',
					'id'    => 'dhl24_parcel',
				),
				array(
					'name'     => __( 'Parcel type', 'woocommerce-dhl24' ),
					'desc'     => __( 'Default parcel type.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[piece_type]',
					'type'     => 'select',
					'options'  => array(
						'ENVELOPE' => __( 'Envelope', 'woocommerce-dhl24' ),
						'PACKAGE'  => __( 'Package', 'woocommerce-dhl24' ),
						'PALLET'   => __( 'Pallet', 'woocommerce-dhl24' ),
					),
					'default'  => $default['piece_type'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Parcel width [cm]', 'woocommerce-dhl24' ),
					'desc'     => __( 'Default parcel width [cm].', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[piece_width]',
					'type'     => 'text',
					'default'  => $default['piece_width'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Parcel height [cm]', 'woocommerce-dhl24' ),
					'desc'     => __( 'Default parcel height [cm].', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[piece_height]',
					'type'     => 'text',
					'default'  => $default['piece_height'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Parcel length [cm]', 'woocommerce-dhl24' ),
					'desc'     => __( 'Default parcel length [cm].', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[piece_length]',
					'type'     => 'text',
					'default'  => $default['piece_length'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Parcel weight [kg]', 'woocommerce-dhl24' ),
					'desc'     => __( 'Default parcel weight [kg].', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[piece_weight]',
					'type'     => 'text',
					'default'  => $default['piece_weight'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Content', 'woocommerce-dhl24' ),
					'desc'     => __( 'Default content.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[content]',
					'type'     => 'text',
					'default'  => $default['content'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Comment', 'woocommerce-dhl24' ),
					'desc'     => __( 'Default comment.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[comment]',
					'type'     => 'text',
					'default'  => $default['comment'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Reference', 'woocommerce-dhl24' ),
					'desc'     => __( 'Shipment reference number.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[reference]',
					'type'     => 'text',
					'default'  => $default['reference'],
					'desc_tip' => true,
				),
				array(
					'title'    => __( 'Cost centre', 'woocommerce-dhl24' ),
					'desc'     => __( 'Cost centre.', 'woocommerce-dhl24' ),
					'id'       => Defaults::OPTION_NAME . '[costs_center]',
					'type'     => 'text',
					'default'  => $default['costs_center'],
					'desc_tip' => true,
				),
				array(
					'type' => 'sectionend',
					'id'   => 'dhl24_parcel',
				),
			);

		$settings = apply_filters( 'woocommerce_settings_pages', $settings );

		return $settings;
	}
}
