<?php
/**
 * Plugin main class.
 *
 * @package ILabs\WoocommerceDHL24
 */

declare (strict_types=1);
namespace ILabs\WoocommerceDHL24;

use ILabs\WoocommerceDHL24\Controller\AdminController;
use ILabs\WoocommerceDHL24\Controller\OrderController;
use ILabs\WoocommerceDHL24\Controller\CheckoutController;
use ILabs\WoocommerceDHL24\Controller\DownloadController;
use ILabs\WoocommerceDHL24\Controller\SettingsController;
use ILabs\WoocommerceDHL24\Controller\ViewOrderController;

/**
 * Main plugin class. The most important flow decisions are made here.
 */
class Plugin {
	/**
	 * Plugin options
	 *
	 * @var PluginOptions Plugin options.
	 */
	private $plugin_options;

	/**
	 * Plugin constructor.
	 *
	 * @param string $file The filename of plugin.
	 */
	public function __construct( string $file ) {
		$this->plugin_options = new PluginOptions();
		$this->plugin_options->set_plugin_file( $file );
		$dirname = dirname( $file );
		$this->plugin_options->set_plugin_dir( $dirname );
		$this->plugin_options->set_plugin_namespace( substr( $dirname, strrpos( $dirname, '/' ) + 1 ) );
		$this->plugin_options->set_plugin_url( \plugins_url( \dirname( \plugin_basename( $file ) ) ) );
		$this->plugin_options->set_plugin_version( '1.0.0' );
	}

	/**
	 * Initializes plugin external state.
	 *
	 * The plugin internal state is initialized in the constructor and the plugin should be internally consistent after creation.
	 * The external state includes hooks execution, communication with other plugins, integration with WC etc.
	 *
	 * @return void
	 */
	public function init() {
		$this->hooks();
	}

	/**
	 * Integrate with WordPress and with other plugins using action/filter system.
	 *
	 * @return void
	 */
	protected function hooks() {
		add_action( 'plugins_loaded', array( $this, 'load' ) );
	}

	/**
	 * Load plugin
	 */
	public function load() {
		$controllers = array(
			new DownloadController(),
			new SettingsController( $this->plugin_options ),
			new AdminController( $this->plugin_options ),
			new OrderController( $this->plugin_options ),
			new CheckoutController( $this->plugin_options ),
			new ViewOrderController( $this->plugin_options ),
		);

		foreach ( $controllers as $controller ) {
			$controller->init();
		};
	}
}
