<?php
/**
 * Class ServiceRepository.
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\Repository;

use ILabs\WoocommerceDHL24\Exception\RepositoryException;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\PostalCodeServices;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Method\GetPostalCodeServices;

/**
 * ServiceRepository
 */
class ServiceRepository extends AbstractRepository {

	/**
	 * Fetch service
	 *
	 * @param  string    $post_code Postal code.
	 * @param  \DateTime $pickup_date Date for which the availability of services is checked .
	 * @return PostalCodeServices
	 * @throws RepositoryException If error.
	 */
	public function fetch_service( string $post_code, \DateTime $pickup_date ): PostalCodeServices {
		$post_code = $this->formatter->post_code( $post_code );
		$params    = new GetPostalCodeServices( $this->auth );
		$params->setPostCode( $post_code );
		$params->setPickupDate( $pickup_date );

		try {
			$postal_code_services = $this->web_api_client->getPostalCodeServices( $params );
		} catch ( \Exception $e ) {
			throw new RepositoryException( $e, $e->getMessage() );
		}
		return $postal_code_services;
	}
}
