<?php
/**
 * Create shipment
 *
 * @package ILabs\WoocommerceDHL24
 * @var array $args {
 *   Array of arguments.
 *   @type int      order_id
 *   @type WC_Order order
 *   @type string   shipping_method_id
 *   @type string   shipment_id
 *   @type array    label_exp_dates
 *   @type array    labels_data
 * }
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

use ILabs\WoocommerceDHL24\Helper\Option;
use ILabs\WoocommerceDHL24\Helper\Param;
use ILabs\WoocommerceDHL24\Helper\View;

do_action( 'dhl24_notices' );
if ( empty( $args ) ) {
	return;
}
/** Order @var WC_Order $wc_order */
$wc_order   = $args['order'];
$order_data = $wc_order->get_data();
$view       = new View();
$name       = $order_data['shipping']['company'];
if ( empty( $name ) ) {
	$name = $order_data['shipping']['first_name'] . ' ' . $order_data['shipping']['last_name'];
}
$servicepoint_shipping_methods = Param::get_instance()->get_value( 'servicepoint_shipping_methods' );
$defaults_data                 = Option::get_instance()->get_data();
if ( count( $args['labels_data'] ) ) {
	$labels_data                   = $args['labels_data'][0];
	$defaults_data['content']      = $labels_data->getContent();
	$defaults_data['comment']      = $labels_data->getComment();
	$defaults_data['reference']    = $labels_data->getReference();
	$billing                       = $labels_data->getBilling();
	$defaults_data['costs_center'] = $billing->getCostsCenter();
}

?>
<div class="wrap">
	<h1 class="wp-heading-inline">
		<?php esc_html_e( 'Return shipment', 'woocommerce-dhl24' ); ?>
	</h1>
	<hr class="wp-header-end">
	<div class="clear"></div>
	<div class="container">
		<div class="row">
			<div class="col-6 info-col bl">
				<div class="info-col__text">
					<?php esc_html_e( 'Sender', 'woocommerce-dhl24' ); ?>:
				</div>
				<div class="info-col__title">
					<?php echo esc_html( $name ); ?>
				</div>
				<div class="info-col__text">
					<?php echo $view->esc_wp_shipping_address($order_data['shipping']); // phpcs:ignore?> <br />
					<?php echo esc_html( $order_data['shipping']['first_name'] . ' ' . $order_data['shipping']['last_name'] ); ?><br />
					<?php echo esc_html( $order_data['billing']['email'] ); ?>, <?php echo esc_html( $order_data['billing']['phone'] ); ?>
				</div>
			</div>
			<div class="col-6 info-col br">
				<div class="info-col__text">
					<?php esc_html_e( 'Recipient', 'woocommerce-dhl24' ); ?>:
				</div>
				<div class="info-col__title">
					<?php echo esc_html( Option::get_instance()->get_value( 'name' ) ); ?>
				</div>
				<div class="info-col__text">
					<?php echo $view->esc_company_return_address(); // phpcs:ignore?> <br>
				</div>
				<div class="info-col__text"><br />
					<?php esc_html_e( 'Payer', 'woocommerce-dhl24' ); ?>: <?php echo esc_html( Option::get_instance()->get_value( 'return_sap' ) ); ?><br />
					<?php esc_html_e( 'Payment form', 'woocommerce-dhl24' ); ?>: <?php echo esc_html( 'BANK' ); ?>
				</div>
			</div>
		</div>
		<div>
			<div class="row">
				<div class="col-12 info-col__title">
					<?php esc_html_e( 'Order details', 'woocommerce-dhl24' ); ?>
				</div>
			</div>
			<?php foreach ( $wc_order->get_items() as $item_id => $item ) : ?>
				<div class="row">
					<div class="col-4">
						<?php echo wp_kses_post( $item->get_name() ); ?>
					</div>
					<div class="col-1">
						<small class="times">&times;</small> <?php echo esc_html( $item->get_quantity() ); ?>
					</div>
					<div class="col-1 text-right">
						<?php echo wc_price( $item->get_total(), array( 'currency' => $wc_order->get_currency() ) ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
					</div>
				</div>
			<?php endforeach; ?>
			<div class="row mb-1">
				<div class="col-5 text-right">
					<?php esc_html_e( 'Total', 'woocommerce-dhl24' ); ?>:
				</div>
				<div class="col-1 text-right">
					<?php echo wc_price( $wc_order->get_total(), array( 'currency' => $wc_order->get_currency() ) ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
				</div>
			</div>
			<div class="row bb">
				<div class="col-12">
					<p><?php printf( /* translators: %s: payment method */ esc_html__( 'Payment via %s', 'woocommerce-dhl24' ), esc_html( $wc_order->get_payment_method_title() ) ); ?></p>
				</div>
			</div>
		</div>
		<div class="row">
			<div class="col-12 info-col__title">
				<?php esc_html_e( 'Shipment details', 'woocommerce-dhl24' ); ?>
			</div>
		</div>
		<form id="dhl24-return-shipment" method="post" action="#" onsubmit="return false;">
			<input type="hidden" name="action" value="dhl24_return_shipment">
			<input type="hidden" name="return_shipment[_nonce]" value="<?php echo esc_attr( $args['_nonce'] ); ?>">
			<input type="hidden" name="return_shipment[order_id]" value="<?php echo esc_attr( $wc_order->get_id() ); ?>">
			<input type="hidden" name="return_shipment[shipment_id]" value="<?php echo esc_attr( $args['shipment_id'] ); ?>">
			<input type="hidden" name="return_shipment[shipping_method]" value="<?php echo esc_attr( $args['shipping_method_id'] ); ?>">
			<div class="row">
				<div class="col-12">
					<table class="dhl24-table-piece">
						<tbody id="dhl24-pieces" data-prototype="<?php echo esc_attr( $view->esc_add_piece_row( $args['shipping_method_id'], '__index__' ) ); ?>">
							<?php
							foreach ( $args['labels_data'] as $labels_data ) :
								foreach ( $labels_data->getPieceList() as $key => $piece ) :
									$values = array(
										'piece_quantity' => $piece->getQuantity(),
										'piece_weight'   => $piece->getWeight(),
										'piece_width'    => $piece->getWidth(),
										'piece_height'   => $piece->getHeight(),
										'piece_length'   => $piece->getLength(),
										'piece_type'     => $piece->getType(),
										'piece_non_standard' => $piece->getNonStandard(),
										'piece_euro_return' => $piece->getEuroReturn(),
									);
									?>
							<?php echo $view->esc_add_piece_row( $args['shipping_method_id'], $key, $values ); // phpcs:ignore?>
							<?php endforeach; ?>
							<?php endforeach; ?>
						</tbody>
					</table>
				</div>
			</div>
			<div class="row">
				<div class="col-3">
					<input class="dhl24_content" type="text" name="return_shipment[content]" value="<?php echo esc_attr( $defaults_data['content'] ); ?>" placeholder="<?php esc_attr_e( 'Content', 'woocommerce-dhl24' ); ?>: *" required="required">
				</div>
				<div class="col-4">
					<input class="dhl24_comment" type="text" name="return_shipment[comment]" value="<?php echo esc_attr( $defaults_data['comment'] ); ?>" placeholder="<?php esc_attr_e( 'Notes', 'woocommerce-dhl24' ); ?>">
				</div>
				<div class="col-3">
					<input class="dhl24_reference" type="text" name="return_shipment[reference]" value="<?php echo esc_attr( $defaults_data['reference'] ); ?>" placeholder="<?php esc_attr_e( 'Reference', 'woocommerce-dhl24' ); ?>">
				</div>
				<div class="col-2">
					<input class="dhl24_costs_center" type="text" name="return_shipment[costs_center]" value="<?php echo esc_attr( $defaults_data['costs_center'] ); ?>" placeholder="<?php esc_attr_e( 'CC', 'woocommerce-dhl24' ); ?>">
				</div>
			</div>
			<div class="row">
				<div class="col-12 info-col__title">
					<?php esc_html_e( 'Delivery', 'woocommerce-dhl24' ); ?>
				</div>
				<div class="col-5">
					<div class="form__field">
						<label for="dhl24_label_exp_date" class="required"><?php esc_html_e( 'Label expiry date (only for the domestic return label)', 'woocommerce-dhl24' ); ?> <span class="required">*</span></label>
						<input id="dhl24_label_exp_date" type="text" name="return_shipment[label_exp_date]" value="<?php echo esc_attr( $args['label_exp_date'] ); ?>" required="required">
					</div>
					<?php if ( 'dhl24_service_zk' === $args['shipping_method_id'] ) : ?>
					<div class="form__field">
						<input type="checkbox" name="return_shipment[book_courier]" value="1" id="book_courier"
						<?php if ( 'yes' === $defaults_data['return_order_courier'] ) : ?>
							checked="checked"
						<?php endif; ?>
						/><label for="book_courier"><?php esc_html_e( 'The possibility of sending a return shipment by courier', 'woocommerce-dhl24' ); ?></label>
					</div>
					<?php endif; ?>
				</div>
				<div class="col-7">
					<h4><?php esc_html_e( 'Select special services', 'woocommerce-dhl24' ); ?></h4>
					<div class="row">
						<div class="col-4">
							<div class="form__field">
								<input type="checkbox" name="return_shipment[service][insurance]" value="1" id="service_insurance" /><label for="service_insurance"><?php esc_html_e( 'Shipment insurance', 'woocommerce-dhl24' ); ?></label>
							</div>
						</div>
						<div class="col-8">
							<div class="form__field">
								<input type="text" name="return_shipment[service][insuranceValue]" value="" placeholder="<?php esc_attr_e( 'Value', 'woocommerce-dhl24' ); ?>">
								<span><?php esc_html_e( 'PLN', 'woocommerce-dhl24' ); ?></span>
							</div>
						</div>
					</div>
				</div>
				<div class="col-12 text-center pb-1 pt-1">
					<button class="button btn" type="submit"><?php esc_html_e( 'Save' ); // phpcs:ignore WordPress.WP.I18n.MissingArgDomain ?></button>
				</div>
			</div>
		</form>
	</div>
</div>
