<?php
/**
 * Shipment
 *
 * @package ILabs\WoocommerceDHL24
 *
 * @var array $args {
 *   Array of arguments.
 *   @type int           shipment_id
 *   @type LabelsData    labels_data
 *   @type TrackAndTrace tracking
 *   @type array         piece_totals
 *   @type int           order_id
 * }
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

use ILabs\WoocommerceDHL24\Helper\View;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\LabelsData;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\TrackAndTrace;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\TrackAndTraceEvent;

do_action( 'dhl24_notices' );
$view = new View();

/**
 * LabelsData
 *
 * @var LabelsData */
$labels_data   = $args['labels_data'];
$sender        = $labels_data->getShipper();
$recipient     = $labels_data->getReceiver();
$billing       = $labels_data->getBilling();
$shipment_time = $labels_data->getShipmentTime();
$service       = $labels_data->getService();
$is_sp_label   = null === $labels_data->getServicepoint()->getServicePointAccountNumber() ? false : true;
?>
<div class="wrap">
	<h1 class="wp-heading-inline">
		<?php printf( /* translators: %s: Shipment ID */ esc_html__( 'Details of shipment no %s', 'woocommerce-dhl24' ), esc_html( $args['shipment_id'] ) ); ?>
	</h1>
	<hr class="wp-header-end">
	<div class="clear"></div>
	<div class="container">
		<div class="row">
			<div class="col-6 info-col bl">
				<div class="info-col__text">
					<?php esc_html_e( 'Sender', 'woocommerce-dhl24' ); ?>:
				</div>
				<div class="info-col__title">
					<?php echo esc_html( $sender->getName() ); ?>
				</div>
				<div class="info-col__text">
					<?php echo $view->esc_sender_address( $sender, $service->getProduct() ); // phpcs:ignore ?> <br>
				</div>
				<?php if ( 'SHIPPER' === $billing->getShippingPaymentType() ) : ?>
				<div class="info-col__text">
					<?php echo $view->esc_billing( $billing ); // phpcs:ignore ?>
				</div>
				<?php endif; ?>
			</div>
			<div class="col-6 info-col br">
				<div class="info-col__text">
					<?php esc_html_e( 'Recipient', 'woocommerce-dhl24' ); ?>:
				</div>
				<div class="info-col__title">
					<?php echo esc_html( $recipient->getName() ); ?>
				</div>
				<div class="info-col__text">
					<?php echo $view->esc_recipient_address( $recipient ); // phpcs:ignore ?> <br>
				</div>
				<?php if ( 'RECEIVER' === $billing->getShippingPaymentType() ) : ?>
				<div class="info-col__text">
					<?php echo $view->esc_billing( $billing ); // phpcs:ignore ?>
				</div>
				<?php endif; ?>
			</div>
		</div>
		<div class="row">
			<div class="col-12 info-col__title">
				<?php esc_html_e( 'Shipment details', 'woocommerce-dhl24' ); ?>
			</div>
			<div class="col-4 info-col bl">
				<div class="info-col__text">
					<div><?php esc_html_e( 'Shipping service type', 'woocommerce-dhl24' ); ?>:</div>
					<span class="info-col__text--strong"><?php echo esc_html( $labels_data->getLabelHeader() ); ?></span>
					<div><?php esc_html_e( 'Parcels', 'woocommerce-dhl24' ); ?>: <?php echo esc_html( $args['piece_totals']['PACKAGE'] ); ?></div>
					<div><?php esc_html_e( 'Envelopes', 'woocommerce-dhl24' ); ?>: <?php echo esc_html( $args['piece_totals']['ENVELOPE'] ); ?></div>
					<div><?php esc_html_e( 'Pallets', 'woocommerce-dhl24' ); ?>: <?php echo esc_html( $args['piece_totals']['PALLET'] ); ?></div>
					<div><?php esc_html_e( 'Sum weight of the parcels', 'woocommerce-dhl24' ); ?>: <?php echo esc_html( $args['piece_totals']['weight'] ); ?> <?php esc_html_e( 'kg', 'woocommerce-dhl24' ); ?></div>
				</div>
			</div>
			<div class="col-4 info-col ">
				<div class="info-col__text">
					<?php $special_services = $view->esc_special_services( $service ); ?>
					<?php if ( ! empty( $special_services ) ) : ?>
					<div><?php esc_html_e( 'Special services', 'woocommerce-dhl24' ); ?>:</div>
					<div><?php echo $special_services; // phpcs:ignore ?></div>
					<?php endif; ?>
					<div><?php esc_html_e( 'Content', 'woocommerce-dhl24' ); ?>:</div>
					<div><?php echo esc_html( $labels_data->getContent() ); ?></div>
				</div>
			</div>
			<div class="col-4 info-col bl">
				<?php if ( in_array( $service->getProduct(), array( 'ZK', 'ZC' ), true ) ) : ?>
				<div class="info-col__bold mb-3">
					<?php esc_html_e( 'Label expiry date', 'woocommerce-dhl24' ); ?>:
				</div>
				<div class="info-col__date-wrap">
					<div class="info-col__text lh-20">
						<div><?php echo esc_html( $shipment_time->getLabelExpDate() ); ?></div>
					</div>
				</div>
				<?php else : ?>
				<div class="info-col__bold mb-3">
					<?php esc_html_e( 'Shipment date', 'woocommerce-dhl24' ); ?>:
				</div>
				<div class="info-col__date-wrap">
					<div class="info-col__text lh-20">
						<div><?php echo esc_html( $shipment_time->getShipmentDate() ); ?></div>
						<?php if ( ! empty( $shipment_time->getShipmentStartHour() ) ) : ?>
						<div><?php esc_html_e( 'During hours', 'woocommerce-dhl24' ); ?>: <?php echo esc_html( $shipment_time->getShipmentStartHour() ); ?> - <?php echo esc_html( $shipment_time->getShipmentEndHour() ); ?></div>
						<?php endif; ?>
					</div>
				</div>
				<?php endif; ?>
			</div>
		</div>
		<div class="row">
			<div class="col-12 info-col__title">
				<?php esc_html_e( 'Comments', 'woocommerce-dhl24' ); ?>
			</div>
			<div class="col-12 info-col bl">
				<div class="info-col__text">
					<?php echo esc_html( $labels_data->getComment() ); ?>
				</div>
			</div>
		</div>
		<div class="row">
			<div class="col-12 info-col__title">
			<?php esc_html_e( 'Shipment tracking log', 'woocommerce-dhl24' ); ?>
			</div>
			<div class="col-12 info-col bl">
<?php
/**
 * TrackAndTrace
 *
 * @var TrackAndTrace
 */
$track_and_trace = $args['tracking'];
$received_by     = $track_and_trace->getReceivedBy();
if ( ! empty( $received_by ) ) {
	?>
<div class="notice notice-success">
	<?php /* translators: %s: Shipment ID */ printf( esc_html__( 'Shipment received by %s.', 'woocommerce-dhl24' ), esc_html( $received_by ) ); ?>
</div>
	<?php
};
?>
<ul>
	<?php
	/**
	 * Loop
	 *
	 * @var TrackAndTraceEvent $event
	 */
	foreach ( $track_and_trace->getEvents() as $event ) {
		?>
		<li>
			<span><?php echo esc_html( $event->getTimestamp() ); ?></span>
			<span><?php echo esc_html( $event->getStatus() ); ?></span>
			<span><?php echo esc_html( $event->getTerminal() ); ?></span>
			<span><?php echo esc_html( $event->getDescription() ); ?></span>
		</li>
		<?php
	}
	?>
</ul>
			</div>
		</div>
		<?php if ( empty( $labels_data->getDispatchNotificationNumber() ) ) : ?>
		<div class="row pb-1 pt-1">
			<div class="col-12 text-center">
				<a class="button btn" href="<?php echo esc_url( add_query_arg( array( 'path' => '/order_courier', 'ids' => $args['shipment_id'] ), $view->admin_url() ) ); // phpcs:ignore ?>"><?php esc_html_e( 'Book a courier', 'woocommerce-dhl24' ); ?></a>
			</div>
		</div>
		<?php endif ?>
		<div class="row pb-1 pt-1">
			<div class="col-12 text-center">
				<ul class="list-inline">
					<li class="list-inline-item"><a href="<?php echo esc_url( $view->download_label_url( $args['shipment_id'], 'lblp', $is_sp_label ) ); ?>"><?php esc_html_e( 'Download BLP label in A4 PDF format', 'woocommerce-dhl24' ); ?></a></li>
					<li class="list-inline-item"><a href="<?php echo esc_url( $view->download_label_url( $args['shipment_id'], 'zblp', $is_sp_label ) ); ?>"><?php esc_html_e( 'Download BLP label in ZPL format', 'woocommerce-dhl24' ); ?></a></li>
					<li class="list-inline-item"><a href="<?php echo esc_url( $view->download_label_url( $args['shipment_id'], 'blp', $is_sp_label ) ); ?>"><?php esc_html_e( 'Download BLP label', 'woocommerce-dhl24' ); ?></a></li>
					<li class="list-inline-item"><a href="<?php echo esc_url( $view->download_scan_url( $args['shipment_id'] ) ); ?>"><?php esc_html_e( 'Download a scan of the consignment note for a completed shipment', 'woocommerce-dhl24' ); ?></a></li>
				</ul>
			</div>
		</div>
		<div class="row pb-1 pt-1">
			<div class="col-12 text-center">
				<?php if ( 'DHL PARCEL RETURN POLSKA' !== $labels_data->getLabelHeader() ) : ?>
				<a class="button btn" href="<?php echo esc_url( add_query_arg( array( 'path' => '/return_shipment', 'id' => $args['shipment_id'] ), $view->admin_url() ) ); // phpcs:ignore ?>"><?php esc_html_e( 'Create return shipment', 'woocommerce-dhl24' ); ?></a>
				<?php endif; ?>
				<?php if ( ! empty( $args['order_id'] ) ) : ?>
				<a class="button btn" href="<?php echo esc_url( admin_url( 'post.php?action=edit&post=' . $args['order_id'] ) ); ?>"><?php esc_html_e( 'Show details of order', 'woocommerce-dhl24' ); ?></a>
				<?php endif; ?>
			</div>
		</div>
	</div>
</div>
<div>
	<div>
		<a href="<?php echo esc_url( add_query_arg( 'path', '/my_parcels', $view->admin_url() ) ); ?>"><?php esc_html_e( 'Back to my parcels list', 'woocommerce-dhl24' ); ?></a>
	</div>
</div>
