<?php
/**
 * Shipment templates page
 *
 * @package ILabs\WoocommerceDHL24
 * @var array $args {
 *   Array of arguments.
 *   @type array  templates
 *   @type string _nonce
 *   @type int                my_shipments_show
 *   @type LabelsDatas        labels
 * }
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

use ILabs\WoocommerceDHL24\Helper\Param;

do_action( 'dhl24_notices' );

$view         = new \ILabs\WoocommerceDHL24\Helper\View();
$parcel_types = Param::get_instance()->get_value( 'parcel_types' );
?>
<div class="wrap">
	<h1 class="wp-heading-inline"><?php esc_html_e( 'Shipment templates', 'woocommerce-dhl24' ); ?></h1>
	<a id="dhl24_add_template" class="page-title-action"><?php esc_html_e( 'Add template', 'woocommerce-dhl24' ); ?></a>
	<hr class="wp-header-end">
	<table class="wp-list-table widefat fixed striped table-view-list">
		<thead>
			<tr>
				<th scope="col"><?php esc_html_e( 'Name', 'woocommerce-dhl24' ); ?></th>
				<th scope="col"><?php esc_html_e( 'Description', 'woocommerce-dhl24' ); ?></th>
				<th scope="col"><?php esc_html_e( 'Options', 'woocommerce-dhl24' ); ?></th>
			</tr>
		</thead>
		<tbody id="the-list">
			<?php if ( 0 === count( $args['templates'] ) ) : ?>
				<tr class="no-items">
					<td class="colspanchange" colspan="3"><?php esc_html_e( 'No templates were found.', 'woocommerce-dhl24' ); ?></td>
				</tr>
			<?php else : ?>
				<?php
				/**
				 * Loop
				 *
				 * @var \ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\ShipmentBasicData $item ShipmentBasicData
				 */
				foreach ( $args['templates'] as $item ) :
					?>
				<tr data-template="<?php echo esc_attr( wp_json_encode( $item ) ); ?>">
					<td><?php echo esc_html( $item['name'] ); ?></td>
					<td>
					<?php
						printf(
							/* translators: %1$s: type, %2$s: quantity */
							esc_html__( 'Type: %1$s | quantity: %2$s | weight: %3$s | width: %4$s | height: %5$s | length: %6$s', 'woocommerce-dhl24' ),
							esc_html( $view->get_parcel_type_name( $item['piece_type'] ) ),
							esc_html( $item['piece_quantity'] ),
							esc_html( $item['piece_weight'] ),
							esc_html( $item['piece_width'] ),
							esc_html( $item['piece_height'] ),
							esc_html( $item['piece_length'] )
						);
					?>
					</td>
					<td>
						<a class="button dhl24_edit_template"><?php esc_html_e( 'Edit', 'woocommerce-dhl24' ); ?></a>
						<a class="button dhl24_delete_template"><?php esc_html_e( 'Delete', 'woocommerce-dhl24' ); ?></a>

					</td>
				</tr>
				<?php endforeach; ?>
			<?php endif; ?>
		</tbody>
		<tfoot>
			<tr>
				<th scope="col"><?php esc_html_e( 'Name', 'woocommerce-dhl24' ); ?></th>
				<th scope="col"><?php esc_html_e( 'Description', 'woocommerce-dhl24' ); ?></th>
				<th scope="col"><?php esc_html_e( 'Options', 'woocommerce-dhl24' ); ?></th>
			</tr>
		</tfoot>

	</table>
	<div class="clear"></div>
</div>
<div id="addTemplateDialog" title="Template" style="display: none;">
	<form id="templateForm">
		<input type="hidden" name="action" value="dhl24_template">
		<input type="hidden" name="template[_nonce]" value="<?php echo esc_attr( $args['_nonce'] ); ?>">
		<input id="dhl24_template_id" type="hidden" name="template[id]" value="">
		<div class="row mb-1">
			<div class="col-12">
				<label class="input-text" for="dhl24_template_name"><?php esc_html_e( 'Name', 'woocommerce-dhl24' ); ?></label>
				<input class="input-flex" id="dhl24_template_name" type="text" name="template[name]" value="" required="required">
			</div>
		</div>
		<div class="row mb-1">
			<div class="col-4">
				<label class="input-text" for="dhl24_template_piece_type"><?php esc_html_e( 'Piece type', 'woocommerce-dhl24' ); ?></label>
				<select id="dhl24_template_piece_type" name="template[piece_type]">
					<?php foreach ( $parcel_types as $value => $name ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>"><?php echo esc_html( $name ); ?></option>
					<?php endforeach; ?>
				</select>
			</div>
			<div class="col-4">
				<label class="input-text" for="dhl24_template_piece_quantity"><?php esc_html_e( 'Quantity', 'woocommerce-dhl24' ); ?></label>
				<input id="dhl24_template_piece_quantity" type="text" name="template[piece_quantity]" value="" required="required">
			</div>
			<div class="col-4">
				<label class="input-text" for="dhl24_template_piece_weight"><?php esc_html_e( 'Weight [kg]', 'woocommerce-dhl24' ); ?></label>
				<input id="dhl24_template_piece_weight" type="text" name="template[piece_weight]" value="">
			</div>
		</div>
		<div class="row mb-1">
			<div class="col-4">
				<label class="input-text" for="dhl24_template_piece_width"><?php esc_html_e( 'Width [cm]', 'woocommerce-dhl24' ); ?></label>
				<input id="dhl24_template_piece_width" type="text" name="template[piece_width]" value="">
			</div>
			<div class="col-4">
				<label class="input-text" for="dhl24_template_piece_height"><?php esc_html_e( 'Height [cm]', 'woocommerce-dhl24' ); ?></label>
				<input id="dhl24_template_piece_height" type="text" name="template[piece_height]" value="">
			</div>
			<div class="col-4">
				<label class="input-text" for="dhl24_template_piece_length"><?php esc_html_e( 'Length [cm]', 'woocommerce-dhl24' ); ?></label>
				<input id="dhl24_template_piece_length" type="text" name="template[piece_length]" value="">
			</div>
		</div>
		<div class="row mb-1">
			<div class="col-4">
				<input id="dhl24_template_piece_nonStandard" type="checkbox" name="template[piece_nonStandard]" value="1" />
				<label for="dhl24_template_piece_nonStandard"><?php esc_html_e( 'Non-standard', 'woocommerce-dhl24' ); ?></label>
			</div>
			<div class="col-4">
				<input id="dhl24_template_piece_piece_euroReturn" type="checkbox" name="template[piece_euroReturn]" value="1" />
				<label for="dhl24_template_piece_piece_euroReturn"><?php esc_html_e( 'Pallet return', 'woocommerce-dhl24' ); ?></label>
			</div>
		</div>
		<div class="row mb-1">
			<div class="col-6">
				<label class="input-text" for="dhl24_template_content"><?php esc_html_e( 'Content', 'woocommerce-dhl24' ); ?></label>
				<input class="input-flex" id="dhl24_template_content" type="text" name="template[content]" value="">
			</div>
			<div class="col-6">
				<label class="input-text" for="dhl24_template_comment"><?php esc_html_e( 'Notes', 'woocommerce-dhl24' ); ?></label>
				<input class="input-flex" id="dhl24_template_comment" type="text" name="template[comment]" value="">
			</div>
		</div>
		<div class="row mb-1">
			<div class="col-6">
				<label class="input-text" for="dhl24_template_reference"><?php esc_html_e( 'Reference', 'woocommerce-dhl24' ); ?></label>
				<input class="input-flex" id="dhl24_template_reference" type="text" name="template[reference]" value="">
			</div>
			<div class="col-6">
				<label class="input-text" for="dhl24_template_costs_center"><?php esc_html_e( 'CC', 'woocommerce-dhl24' ); ?></label>
				<input class="input-flex" id="dhl24_template_costs_center" type="text" name="template[costs_center]" value="">
			</div>
		</div>
		<div class="row mb-1">
			<div class="col-3">
				<input id="dhl24_template_service_insurance" type="checkbox" name="template[service_insurance]" value="1" />
				<label for="dhl24_template_service_insurance"><?php esc_html_e( 'Shipment insurance', 'woocommerce-dhl24' ); ?></label>
			</div>
			<div class="col-6">
				<label class="input-text" for="dhl24_template_service_insurance_value"><?php esc_html_e( 'Value', 'woocommerce-dhl24' ); ?></label>
				<input id="dhl24_template_service_insurance_value" type="text" name="template[service_insurance_value]" value="">
				<span><?php esc_html_e( 'PLN', 'woocommerce-dhl24' ); ?></span>
			</div>
			<div class="col-3">
				<input id="dhl24_template_service_predeliveryInformation" type="checkbox" name="template[service_predeliveryInformation]" value="1" />
				<label for="dhl24_template_service_predeliveryInformation"><?php esc_html_e( 'PDI', 'woocommerce-dhl24' ); ?></label>
			</div>
		</div>
	</form>
</div>
